@@ -9,37 +9,14 @@ import time
 from leo.core import leoGlobals as g
 from leo.core import leoImport
 #@+others
-#@+node:ekr.20170221033738.1: ** c_file.reloadSettings & helper
+#@+node:ekr.20170221033738.1: ** c_file.reloadSettings
 @g.commander_command('reload-settings')
 def reloadSettings(self, event=None):
-    """Reload settings in all commanders, or just c."""
+    """Reload settings in all commanders, saving all existing opened files first"""
     lm = g.app.loadManager
-    # Save any changes so they can be seen.
+    # Save any changes so they can be seen, for existing files that are not new/untitled.
     for c2 in g.app.commanders():
-        if c2.isChanged():
-            c2.save()
-    # Read leoSettings.leo and myLeoSettings.leo, using a null gui.
-    lm.readGlobalSettingsFiles()
-    for c in g.app.commanders():
-        # Read the local file, using a null gui.
-        previousSettings = lm.getPreviousSettings(fn=c.mFileName)
-        # Init the config classes.
-        c.initSettings(previousSettings)
-        # Init the commander config ivars.
-        c.initConfigSettings()
-        # Reload settings in all configurable classes
-        c.reloadConfigurableSettings()
-#@+node:ekr.20170221034501.1: *3* function: reloadSettingsHelper
-def reloadSettingsHelper(c):
-    """
-    Reload settings in all commanders, or just c.
-
-    A helper function for reload-settings and reload-all-settings.
-    """
-    lm = g.app.loadManager
-    # Save any changes so they can be seen.
-    for c2 in g.app.commanders():
-        if c2.isChanged():
+        if c2.isChanged() and c2.mFileName:
             c2.save()
     # Read leoSettings.leo and myLeoSettings.leo, using a null gui.
     lm.readGlobalSettingsFiles()
@@ -181,8 +158,8 @@ def importAnyFile(self, event=None):
             ic.importFilesCommand(
                 files=[fn],
                 parent=parent,
+                # Experimental: attempt to use permissive section ref logic.
                 treeType='@auto',  # was '@clean'
-                    # Experimental: attempt to use permissive section ref logic.
             )
             c.redraw()
     c.raise_error_dialogs(kind='read')
@@ -243,8 +220,8 @@ def new(self, event=None, gui=None):
         # g.app.restoreWindowState(c)
     frame.deiconify()
     frame.lift()
+    # Resize the _new_ frame.
     frame.resizePanesToRatio(frame.ratio, frame.secondary_ratio)
-        # Resize the _new_ frame.
     c.frame.createFirstTreeNode()
     lm.createMenu(c)
     lm.finishOpen(c)
@@ -264,14 +241,14 @@ def new(self, event=None, gui=None):
             f"total: {t4-t1:5.2f}"
         )
     return c  # For unit tests and scripts.
-#@+node:ekr.20031218072017.2821: *3* c_file.open_outline
+#@+node:ekr.20031218072017.2821: *3* c_file.open_outline & helper
 @g.commander_command('open-outline')
 def open_outline(self, event=None):
     """Open a Leo window containing the contents of a .leo file."""
     c = self
-    #@+others
+    #@+others  # Defines open_completer function.
     #@+node:ekr.20190518121302.1: *4* function: open_completer
-    def open_completer(c, closeFlag, fileName):
+    def open_completer(c, fileName):
 
         c.bringToFront()
         c.init_error_dialogs()
@@ -280,12 +257,10 @@ def open_outline(self, event=None):
             if g.app.loadManager.isLeoFile(fileName):
                 c2 = g.openWithFileName(fileName, old_c=c)
                 if c2:
+                    # Fix #579: Key bindings don't take for commands defined in plugins.
                     c2.k.makeAllBindings()
-                        # Fix #579: Key bindings don't take for commands defined in plugins.
                     g.chdir(fileName)
                     g.setGlobalOpenDir(fileName)
-                if c2 and closeFlag:
-                    g.app.destroyWindow(c.frame)
             elif c.looksLikeDerivedFile(fileName):
                 # Create an @file node for files containing Leo sentinels.
                 ok = c.importCommands.importDerivedFiles(parent=c.p,
@@ -299,27 +274,14 @@ def open_outline(self, event=None):
         if not ok:
             c.initialFocusHelper()
     #@-others
-        # Defines open_completer function.
-
-    #
-    # Close the window if this command completes successfully?
-
-    closeFlag = (
-        c.frame.startupWindow and
-            # The window was open on startup
-        not c.changed and not c.frame.saved and
-            # The window has never been changed
-        g.app.numberOfUntitledWindows == 1
-            # Only one untitled window has ever been opened
-    )
     table = [
-        ("Leo files", "*.leo *.db"),
+        ("Leo files", "*.leo *.leojs *.db"),
         ("Python files", "*.py"),
         ("All files", "*"),
     ]
     fileName = ''.join(c.k.givenArgs)
     if fileName:
-        c.open_completer(c, closeFlag, fileName)
+        open_completer(c, fileName)
         return
     # Equivalent to legacy code.
     fileName = g.app.gui.runOpenFileDialog(c,
@@ -327,7 +289,7 @@ def open_outline(self, event=None):
         filetypes=table,
         title="Open",
     )
-    open_completer(c, closeFlag, fileName)
+    open_completer(c, fileName)
 #@+node:ekr.20140717074441.17772: *3* c_file.refreshFromDisk
 # refresh_pattern = re.compile(r'^(@[\w-]+)')
 
@@ -348,8 +310,8 @@ def refreshFromDisk(self, event=None):
     b = u.beforeChangeTree(p)
     redraw_flag = True
     at = c.atFileCommands
+    # Fix bug 1090950 refresh from disk: cut node resurrection.
     c.recreateGnxDict()
-        # Fix bug 1090950 refresh from disk: cut node ressurection.
     i = g.skip_id(p.h, 0, chars='@')
     word = p.h[0:i]
     if word == '@auto':
@@ -374,12 +336,10 @@ def refreshFromDisk(self, event=None):
             p.v._deleteAllChildren()
         at.read(p)
     elif word == '@edit':
-        at.readOneAtEditNode(fn, p)
-            # Always deletes children.
+        at.readOneAtEditNode(fn, p)  # Always deletes children.
     elif word == '@asis':
         # Fix #1067.
-        at.readOneAtAsisNode(fn, p)
-            # Always deletes children.
+        at.readOneAtAsisNode(fn, p)  # Always deletes children.
     else:
         g.es_print(f"can not refresh from disk\n{p.h!r}")
         redraw_flag = False
@@ -447,11 +407,11 @@ def save(self, event=None, fileName=None):
             if not fileName:
                 fileName = g.app.gui.runSaveFileDialog(c,
                     title="Save",
-                    filetypes=[("Leo files", "*.leo *.db"),],
+                    filetypes=[("Leo files", "*.leo *.leojs *.db"),],
                     defaultextension=g.defaultLeoFileExtension(c))
         c.bringToFront()
         if fileName:
-            # Don't change mFileName until the dialog has suceeded.
+            # Don't change mFileName until the dialog has succeeded.
             c.mFileName = g.ensure_extension(fileName, g.defaultLeoFileExtension(c))
             c.frame.title = c.computeWindowTitle(c.mFileName)
             c.frame.setTitle(c.computeWindowTitle(c.mFileName))
@@ -516,15 +476,19 @@ def saveAs(self, event=None, fileName=None):
     if not fileName:
         fileName = g.app.gui.runSaveFileDialog(c,
             title="Save As",
-            filetypes=[("Leo files", "*.leo *.db"),],
+            filetypes=[("Leo files", "*.leo *.leojs *.db"),],
             defaultextension=g.defaultLeoFileExtension(c))
     c.bringToFront()
     if fileName:
-        # Fix bug 998090: save file as doesn't remove entry from open file list.
+        # #998090: save file as doesn't remove entry from open file list.
+        g.trace(fileName)
         if c.mFileName:
             g.app.forgetOpenFile(c.mFileName)
-        # Don't change mFileName until the dialog has suceeded.
-        c.mFileName = g.ensure_extension(fileName, g.defaultLeoFileExtension(c))
+        # Don't change mFileName until the dialog has succeeded.
+        if fileName.endswith(('.leo', '.db', '.leojs')):
+            c.mFileName = fileName
+        else:
+            c.mFileName = g.ensure_extension(fileName, g.defaultLeoFileExtension(c))
         # Part of the fix for https://bugs.launchpad.net/leo-editor/+bug/1194209
         c.frame.title = title = c.computeWindowTitle(c.mFileName)
         c.frame.setTitle(title)
@@ -571,7 +535,7 @@ def saveTo(self, event=None, fileName=None, silent=False):
     if not fileName:
         fileName = g.app.gui.runSaveFileDialog(c,
             title="Save To",
-            filetypes=[("Leo files", "*.leo *.db"),],
+            filetypes=[("Leo files", "*.leo *.leojs *.db"),],
             defaultextension=g.defaultLeoFileExtension(c))
     c.bringToFront()
     if fileName:
@@ -966,24 +930,12 @@ def editRecentFiles(self, event=None):
 @g.commander_command('open-recent-file')
 def openRecentFile(self, event=None, fn=None):
     c = self
-    # Automatically close the previous window if...
-    closeFlag = (
-        c.frame.startupWindow and
-            # The window was open on startup
-        not c.changed and not c.frame.saved and
-            # The window has never been changed
-        g.app.numberOfUntitledWindows == 1)
-            # Only one untitled window has ever been opened.
-    if g.doHook("recentfiles1", c=c, p=c.p, v=c.p, fileName=fn, closeFlag=closeFlag):
+    if g.doHook("recentfiles1", c=c, p=c.p, v=c.p, fileName=fn):
         return
     c2 = g.openWithFileName(fn, old_c=c)
     if c2:
         g.app.makeAllBindings()
-    if closeFlag and c2 and c2 != c:
-        g.app.destroyWindow(c.frame)
-        c2.setLog()
-        g.doHook("recentfiles2",
-            c=c2, p=c2.p, v=c2.p, fileName=fn, closeFlag=closeFlag)
+        g.doHook("recentfiles2", c=c2, p=c2.p, v=c2.p, fileName=fn)
 #@+node:tbrown.20080509212202.8: *3* c_file.sortRecentFiles
 @g.commander_command('sort-recent-files')
 def sortRecentFiles(self, event=None):
@@ -1056,7 +1008,7 @@ def setReferenceFile(self, event=None):
     c = self
     fileName = g.app.gui.runOpenFileDialog(c,
             title="Select reference Leo file",
-            filetypes=[("Leo files", "*.leo *.db"),],
+            filetypes=[("Leo files", "*.leo *.leojs *.db"),],
             defaultextension=g.defaultLeoFileExtension(c))
     if not fileName:
         return
@@ -1074,7 +1026,7 @@ def open_theme_file(self, event):
     fn = g.app.gui.runOpenFileDialog(c,
         title="Open Theme File",
         filetypes=[
-            ("Leo files", "*.leo *.db"),
+            ("Leo files", "*.leo *.leojs *.db"),
             ("All files", "*"),
         ],
         defaultextension=g.defaultLeoFileExtension(c),
