@@ -4,6 +4,9 @@
 #@@first
 """Outline commands that used to be defined in leoCommands.py"""
 import xml.etree.ElementTree as ElementTree
+import json
+from collections import defaultdict
+from typing import Any
 from leo.core import leoGlobals as g
 from leo.core import leoNodes
 from leo.core import leoFileCommands
@@ -24,7 +27,6 @@ def copyOutline(self, event=None):
 def copyOutlineAsJSON(self, event=None):
     """Copy the selected outline to the clipboard in json format."""
     # Copying an outline has no undo consequences.
-    import json
     #@+others  # Define helper functions
     #@+node:ekr.20220314072801.1: *4* function: json_globals
     def json_globals(c):
@@ -94,7 +96,7 @@ def pasteOutline(self, event=None, s=None, undoFlag=True):
     c.endEditing()
     if not s or not c.canPasteOutline(s):
         return None  # This should never happen.
-    isLeo = g.match(s, 0, g.app.prolog_prefix_string)
+    isLeo = s.lstrip().startswith("{") or g.match(s, 0, g.app.prolog_prefix_string)
     if not isLeo:
         return None
     # Get *position* to be pasted.
@@ -137,9 +139,6 @@ def pasteOutlineRetainingClones(self, event=None, s=None, undoFlag=True):
     c.endEditing()
     if not s or not c.canPasteOutline(s):
         return None  # This should never happen.
-    isLeo = g.match(s, 0, g.app.prolog_prefix_string)
-    if not isLeo:
-        return None
     # Get *position* to be pasted.
     pasted = c.fileCommands.getLeoOutlineFromClipboardRetainingClones(s)
     if not pasted:
@@ -202,8 +201,18 @@ def computeVnodeInfoDict(c):
 #@+node:vitalije.20200529105105.1: *3* c_oc.pasteAsTemplate
 @g.commander_command('paste-as-template')
 def pasteAsTemplate(self, event=None):
+    """Paste as template clones only nodes that were already clones"""
     c = self
     p = c.p
+
+    s = g.app.gui.getTextFromClipboard()
+    if not s or not c.canPasteOutline(s):
+        return None  # This should never happen.
+
+    isJson = False
+    if s.lstrip().startswith("{"):
+        isJson = True
+
     #@+others
     #@+node:vitalije.20200529112224.1: *4* skip_root
     def skip_root(v):
@@ -233,18 +242,32 @@ def pasteAsTemplate(self, event=None):
 
         skipping the descendants of already seen nodes.
         """
-        chgnx = xv.attrib.get('t')
+
+        if not isJson:
+            chgnx = xv.attrib.get('t')
+        else:
+            chgnx = xv.get('gnx')
+
         b = bodies[chgnx]
         gnx = translation.get(chgnx)
         if gnx in seen:
             yield parent_gnx, gnx, heads.get(gnx), b
         else:
             seen.add(gnx)
-            h = xv[0].text
+            if not isJson:
+                h = xv[0].text
+            else:
+                h = xv.get('vh', '')
             heads[gnx] = h
             yield parent_gnx, gnx, h, b
-            for xch in xv[1:]:
-                yield from viter(gnx, xch)
+            if not isJson:
+                for xch in xv[1:]:
+                    yield from viter(gnx, xch)
+            else:
+                if xv.get('children'):
+                    for xch in xv['children']:
+                        yield from viter(gnx, xch)
+
     #@+node:vitalije.20200529114857.1: *4* getv
     gnx2v = c.fileCommands.gnxDict
     def getv(gnx):
@@ -311,18 +334,41 @@ def pasteAsTemplate(self, event=None):
         pasted.parents.append(vpar)
         c.redraw(newp)
     #@-others
-    xroot = ElementTree.fromstring(g.app.gui.getTextFromClipboard())
-    xvelements = xroot.find('vnodes')  # <v> elements.
-    xtelements = xroot.find('tnodes')  # <t> elements.
 
-    bodies, uas = leoFileCommands.FastRead(c, {}).scanTnodes(xtelements)
+    xvelements: Any
+    xtelements: Any
 
-    root_gnx = xvelements[0].attrib.get('t')  # the gnx of copied node
+    if not isJson:
+        xroot = ElementTree.fromstring(g.app.gui.getTextFromClipboard())
+        xvelements = xroot.find('vnodes')  # <v> elements.
+        xtelements = xroot.find('tnodes')  # <t> elements.
+        bodies, uas = leoFileCommands.FastRead(c, {}).scanTnodes(xtelements)
+        root_gnx = xvelements[0].attrib.get('t')  # the gnx of copied node
+    else:
+        xroot = json.loads(g.app.gui.getTextFromClipboard())
+        xvelements = xroot.get('vnodes')  # <v> elements.
+        xtelements = xroot.get('tnodes')  # <t> elements.
+        # bodies, uas = leoFileCommands.FastRead(c, {}).scanTnodes(xtelements)
+        bodies = leoFileCommands.FastRead(c, {}).scanJsonTnodes(xtelements)
+
+        def addBody(node):
+            if not hasattr(bodies, node['gnx']):
+                bodies[node['gnx']] = ''
+            if node.get('children'):
+                for child in node['children']:
+                    addBody(child)
+
+        # generate bodies for all possible nodes, not just non-empty bodies.
+        addBody(xvelements[0])
+        uas = defaultdict(dict)
+        uas.update(xroot.get('uas', {}))
+        root_gnx = xvelements[0].get('gnx')  # the gnx of copied node
+
+    # outside will contain gnxes of nodes that are outside the copied tree
     outside = {x.gnx for x in skip_root(c.hiddenRootNode)}
-        # outside will contain gnxes of nodes that are outside the copied tree
 
+    # we generate new gnx for each node in the copied tree
     translation = {x: translate_gnx(x) for x in bodies}
-        # we generate new gnx for each node in the copied tree
 
     seen = set(outside)  # required for the treatment of local clones inside the copied tree
 
@@ -449,7 +495,7 @@ def contractNodeOrGoToParent(self, event=None):
                     child.contract()
                     if child.hasChildren():
                         redraw = True
-        if cc and cc.inChapter and parent.h.startswith('@chapter '):
+        if cc and cc.inChapter() and parent.h.startswith('@chapter '):
             pass
         else:
             c.goToParent()
@@ -683,9 +729,7 @@ def goPrevVisitedNode(self, event=None):
 def goToFirstNode(self, event=None):
     """
     Select the first node of the entire outline.
-
-    But (#2167), go to the first node of a chapter or hoist
-    if Leo is hoisted or within a chapter.
+    Or the first visible node if Leo is hoisted or within a chapter.
     """
     c = self
     p = c.rootPosition()
@@ -707,7 +751,10 @@ def goToFirstVisibleNode(self, event=None):
     c = self
     p = c.firstVisible()
     if p:
-        c.expandOnlyAncestorsOfNode(p=p)
+        if c.sparse_goto_visible:
+            c.expandOnlyAncestorsOfNode(p=p)
+        else:
+            c.treeSelectHelper(p)
         c.redraw()
 #@+node:ekr.20031218072017.2915: *3* c_oc.goToLastNode
 @g.commander_command('goto-last-node')
@@ -735,7 +782,10 @@ def goToLastVisibleNode(self, event=None):
     c = self
     p = c.lastVisible()
     if p:
-        c.expandOnlyAncestorsOfNode(p=p)
+        if c.sparse_goto_visible:
+            c.expandOnlyAncestorsOfNode(p=p)
+        else:
+            c.treeSelectHelper(p)
         c.redraw()
 #@+node:ekr.20031218072017.2916: *3* c_oc.goToNextClone
 @g.commander_command('goto-next-clone')
@@ -910,17 +960,18 @@ def selectVisNext(self, event=None):
 @g.commander_command('dehoist')
 def dehoist(self, event=None):
     """Undo a previous hoist of an outline."""
-    c = self
+    c, cc, tag = self, self.chapterController, '@chapter '
     if not c.p or not c.hoistStack:
         return
-    # Don't de-hoist an @chapter node.
-    if c.chapterController and c.p.h.startswith('@chapter '):
-        if not g.unitTesting:
-            g.es('can not de-hoist an @chapter node.', color='blue')
+    # #2718: de-hoisting an @chapter node is equivalent to selecting the main chapter.
+    if c.p.h.startswith(tag) or c.hoistStack[-1].p.h.startswith(tag):
+        c.hoistStack = []
+        cc.selectChapterByName('main')
         return
     bunch = c.hoistStack.pop()
     p = bunch.p
-    if not p:
+    # Checks 'expanded' property, which was preserved by 'hoist' method
+    if bunch.expanded:
         p.expand()
     else:
         p.contract()
@@ -928,7 +979,6 @@ def dehoist(self, event=None):
     c.redraw()
     c.frame.clearStatusLine()
     c.frame.putStatusLine("De-Hoist: " + p.h)
-    c.undoer.afterDehoist(p, 'DeHoist')
     g.doHook('hoist-changed', c=c)
 #@+node:ekr.20120308061112.9866: *3* c_oc.clearAllHoists
 @g.commander_command('clear-all-hoists')
@@ -942,8 +992,7 @@ def clearAllHoists(self, event=None):
 @g.commander_command('hoist')
 def hoist(self, event=None):
     """Make only the selected outline visible."""
-    c = self
-    p = c.p
+    c, p = self, self.p
     if not p:
         return
     # Don't hoist an @chapter node.
@@ -958,7 +1007,6 @@ def hoist(self, event=None):
     c.redraw(p)
     c.frame.clearStatusLine()
     c.frame.putStatusLine("Hoist: " + p.h)
-    c.undoer.afterHoist(p, 'Hoist')
     g.doHook('hoist-changed', c=c)
 #@+node:ekr.20031218072017.1759: ** c_oc.Insert, Delete & Clone commands
 #@+node:ekr.20031218072017.1762: *3* c_oc.clone
@@ -1290,8 +1338,7 @@ def moveMarked(self, event=None):
         if p.isMarked() and not parent.isAncestorOf(p):
             moved.append(p.copy())
             next = p.positionAfterDeletedTree()
-            p.moveToLastChildOf(parent)
-                # This does not change parent's position.
+            p.moveToLastChildOf(parent)  # This does not change parent's position.
             p = next
         else:
             p.moveToThreadNext()
