@@ -34,14 +34,13 @@ class ConvertAtRoot:
     root = None  # Root of @root tree.
     root_pat = re.compile(r'^@root\s+(.+)$', re.MULTILINE)
     section_pat = re.compile(r'\s*<\<.+>\>')
-    units: List[Any] = []
-        # List of positions containing @unit.
+    units: List[Any] = []  # List of positions containing @unit.
 
     #@+others
     #@+node:ekr.20210308044128.1: *3* atRoot.check_move
     def check_clone_move(self, p, parent):
         """
-        Return False if p or any of p's descendents is a clone of parent
+        Return False if p or any of p's descendants is a clone of parent
         or any of parents ancestors.
         """
         # Like as checkMoveWithParentWithWarning without warning.
@@ -89,7 +88,7 @@ class ConvertAtRoot:
     #@+node:ekr.20210307075117.1: *3* atRoot.do_root
     def do_root(self, p):
         """
-        Make all necessary clones for section defintions.
+        Make all necessary clones for section definitions.
         """
         for p in p.self_and_subtree():
             self.make_clones(p)
@@ -744,7 +743,7 @@ class GitDiffController:
             devel_rev = devel_rev[:8]
             self.diff_two_revs(
                 rev1=devel_rev,  # Before: Latest devel commit.
-                rev2='HEAD',  # After: Lastest branch commit
+                rev2='HEAD',  # After: Latest branch commit
             )
         else:
             g.es_print('FAIL: git rev-parse devel')
@@ -1047,10 +1046,10 @@ class GitDiffController:
         root.copyTreeFromSelfTo(hidden_root, copyGnxs=True)
         hidden_root.h = fn + ':' + rev if rev else fn
         # Set at.encoding first.
+        # Must be called before at.scanAllDirectives.
         at.initReadIvars(hidden_root, fn)
-            # Must be called before at.scanAllDirectives.
+        # Sets at.startSentinelComment/endSentinelComment.
         at.scanAllDirectives(hidden_root)
-            # Sets at.startSentinelComment/endSentinelComment.
         new_public_lines = g.splitLines(s)
         old_private_lines = at.write_at_clean_sentinels(hidden_root)
         marker = x.markerFromFileLines(old_private_lines, fn)
