@@ -2,29 +2,30 @@
 #@+leo-ver=5-thin
 #@+node:ekr.20150514040138.1: * @file ../commands/helpCommands.py
 #@@first
-'''Leo's help commands.'''
+"""Leo's help commands."""
 #@+<< imports >>
 #@+node:ekr.20150514050337.1: ** << imports >> (helpCommands.py)
-import leo.core.leoGlobals as g
-from leo.commands.baseCommands import BaseEditCommandsClass as BaseEditCommandsClass
+import io
 import re
 import sys
+import textwrap
+from leo.core import leoGlobals as g
+from leo.commands.baseCommands import BaseEditCommandsClass
 #@-<< imports >>
 
 def cmd(name):
-    '''Command decorator for the helpCommands class.'''
+    """Command decorator for the helpCommands class."""
     return g.new_cmd_decorator(name, ['c', 'helpCommands',])
 
 #@+others
 #@+node:ekr.20160514121110.1: ** class HelpCommandsClass
 class HelpCommandsClass(BaseEditCommandsClass):
-    '''A class to load files into buffers and save buffers to files.'''
-    # pylint: disable=anomalous-backslash-in-string
+    """A class to load files into buffers and save buffers to files."""
     #@+others
     #@+node:ekr.20150514063305.373: *3* help
     @cmd('help')
-    def help(self, event=None):
-        '''Prints and introduction to Leo's help system.'''
+    def help_command(self, event=None):
+        """Prints an introduction to Leo's help system."""
         #@+<< define rst_s >>
         #@+node:ekr.20150514063305.374: *4* << define rst_s >> (F1)
         #@@language rest
@@ -63,12 +64,12 @@ class HelpCommandsClass(BaseEditCommandsClass):
     #@+node:ekr.20150514063305.375: *3* helpForAbbreviations
     @cmd('help-for-abbreviations')
     def helpForAbbreviations(self, event=None):
-        '''Prints a discussion of abbreviations.'''
+        """Prints a discussion of abbreviations."""
         #@+<< define s >>
         #@+node:ekr.20150514063305.376: *4* << define s >> (helpForAbbreviations)
         #@@language rest
 
-        s = '''\
+        s = r'''\
 
         About Abbreviations
         -------------------
@@ -126,7 +127,7 @@ class HelpCommandsClass(BaseEditCommandsClass):
     #@+node:ekr.20150514063305.377: *3* helpForAutocompletion
     @cmd('help-for-autocompletion')
     def helpForAutocompletion(self, event=None):
-        '''Prints a discussion of autocompletion.'''
+        """Prints a discussion of autocompletion."""
         #@+<< define s >>
         #@+node:ekr.20150514063305.378: *4* << define s >> (helpForAutocompletion)
         # @pagewidth 40
@@ -242,7 +243,7 @@ class HelpCommandsClass(BaseEditCommandsClass):
     #@+node:ekr.20150514063305.379: *3* helpForBindings
     @cmd('help-for-bindings')
     def helpForBindings(self, event=None):
-        '''Prints a discussion of keyboard bindings.'''
+        """Prints a discussion of keyboard bindings."""
         #@+<< define s >>
         #@+node:ekr.20150514063305.380: *4* << define s >> (helpForBindings)
         # @pagewidth 40
@@ -327,7 +328,7 @@ class HelpCommandsClass(BaseEditCommandsClass):
     #@+node:ekr.20150514063305.381: *3* helpForCommand & helpers
     @cmd('help-for-command')
     def helpForCommand(self, event):
-        '''Prompts for a command name and prints the help message for that command.'''
+        """Prompts for a command name and prints the help message for that command."""
         c, k = self.c, self.c.k
         s = '''\
     Alt-0 (vr-toggle) hides this help message.
@@ -348,7 +349,7 @@ class HelpCommandsClass(BaseEditCommandsClass):
             aList = d.get(stroke, [])
             for bi in aList:
                 if bi.commandName == commandName:
-                    pane = '' if bi.pane == 'all' else ' %s:' % (bi.pane)
+                    pane = '' if bi.pane == 'all' else f" {bi.pane}:"
                     s1 = pane
                     s2 = k.prettyPrintKey(stroke)
                     s3 = bi.commandName
@@ -356,7 +357,7 @@ class HelpCommandsClass(BaseEditCommandsClass):
                     n2 = max(n2, len(s2))
                     data.append((s1, s2, s3),)
         data.sort(key=lambda x: x[1])
-        return ','.join(['%s %s' % (z1, z2) for z1, z2, z3 in data]).strip()
+        return ','.join([f"{z1} {z2}" for z1, z2, z3 in data]).strip()
     #@+node:ekr.20150514063305.383: *4* helpForCommandFinisher
     def helpForCommandFinisher(self, commandName):
         c, s = self.c, None
@@ -373,11 +374,11 @@ class HelpCommandsClass(BaseEditCommandsClass):
                 else:
                     s = 'no docstring available'
                 # Create the title.
-                s2 = '%s (%s)' % (commandName, bindings) if bindings else commandName
+                s2 = f"{commandName} ({bindings})" if bindings else commandName
                 underline = '+' * len(s2)
-                title = '%s\n%s\n\n' % (s2, underline)
-                if 1: # 2015/03/24
-                    s = title + g.adjustTripleString(s, c.tab_width)
+                title = f"{s2}\n{underline}\n\n"
+                if 1:  # 2015/03/24
+                    s = title + textwrap.dedent(s)
                 else:
                     # Fixes bug 618570:
                     s = title + ''.join([
@@ -418,34 +419,38 @@ class HelpCommandsClass(BaseEditCommandsClass):
 
                 '''
                 #@-<< set s to about help-for-command >>
-            c.putHelpFor(s) # calls g.adjustTripleString.
+            c.putHelpFor(s)
     #@+node:ekr.20150514063305.385: *4* replaceBindingPatterns
     def replaceBindingPatterns(self, s):
-        '''For each instance of the pattern !<command-name>! is s,
-        replace the pattern by the key binding for command-name.'''
+        """
+        For each instance of the pattern !<command-name>! in s,
+        replace the pattern by the key binding for command-name.
+        """
         c = self.c
-        pattern = re.compile('!<(.*)>!')
+        pattern = re.compile(r'!<(.*)>!')
         while True:
             m = pattern.search(s, 0)
-            if m is None: break
+            if m is None:
+                break
             name = m.group(1)
             junk, aList = c.config.getShortcut(name)
             for bi in aList:
                 if bi.pane == 'all':
                     key = c.k.prettyPrintKey(bi.stroke.s)
                     break
-            else: key = '<Alt-X>%s<Return>' % name
-            s = s[: m.start()] + key + s[m.end():]
+            else:
+                key = f"<Alt-X>{name}<Return>"
+            s = s[: m.start()] + key + s[m.end() :]
         return s
     #@+node:ekr.20150514063305.386: *3* helpForCreatingExternalFiles
     @cmd('help-for-creating-external-files')
     def helpForCreatingExternalFiles(self, event=None):
-        '''Prints a discussion of creating external files.'''
+        """Prints a discussion of creating external files."""
         #@+<< define s >>
         #@+node:ekr.20150514063305.387: *4* << define s >> (helpForCreatingExternalFiles)
         #@@language rest
 
-        s = '''
+        s = r'''
 
         Creating External Files
         -------------------------
@@ -576,7 +581,7 @@ class HelpCommandsClass(BaseEditCommandsClass):
     #@+node:ekr.20150514063305.388: *3* helpForDebuggingCommands
     @cmd('help-for-debugging-commands')
     def helpForDebuggingCommands(self, event=None):
-        '''Prints a discussion of of Leo's debugging commands.'''
+        """Prints a discussion of of Leo's debugging commands."""
         #@+<< define s >>
         #@+node:ekr.20150514063305.389: *4* << define s >> (helpForDebuggingCommands)
         # @pagewidth 40
@@ -591,28 +596,23 @@ class HelpCommandsClass(BaseEditCommandsClass):
 
         The following commands are useful for debugging::
 
-            collect-garbage:   Invoke the garbage collector.
-            debug:             Start an external debugger in another process.
-            disable-gc-trace:  Disable tracing of the garbage collector.
-            dump-all-objects:  Print a summary of all existing Python objects.
-            dump-new-objects:  Print a summary of all newly-created Python objects.
-            enable-gc-trace:   Enable tracing of the garbage collector.
-            free-tree-widgets: Free all widgets used in Leo's outline pane.
-            show-focus:        Print information about the requested focus.
-            show-stats:        Print statistics about existing Python objects.
-            show-gc-summary:   Print a brief summary of all Python objects.
-            run-unit-tests:    Run unit tests in the presently selected tree.
-            verbose-dump-objects: Print a more verbose listing of all existing Python objects.
+            debug:               Start an external debugger in another process.
+            dump-node:           Dump c.p.v, including gnx, uA's, etc.
+            gc-collect-garbage:  Invoke the garbage collector.
+            gc-dump-all-objects: Print a summary of all Python objects.
+            gc-show-summary:     Print a brief summary of Python objects.
+            pdb:                 Start Python's debugger.
+            show-focus:          Print information about the requested focus.
+            show-stats:          Print statistics about existing Python objects.
 
-        Leo also has many debugging settings that enable and disable traces.
-        For details, see the node: @settings-->Debugging in leoSettings.leo.
+        Leo's --trace command-line arg can enable traces.
         '''
         #@-<< define s >>
         self.c.putHelpFor(s)
     #@+node:ekr.20150514063305.390: *3* helpForDragAndDrop
     @cmd('help-for-drag-and-drop')
     def helpForDragAndDrop(self, event=None):
-        '''Prints a discussion of of Leo's debugging commands.'''
+        """Prints a discussion of of Leo's debugging commands."""
         #@+<< define s >>
         #@+node:ekr.20150514063305.391: *4* << define s >> (helpForDragAndDrop
         # @pagewidth 40
@@ -651,7 +651,7 @@ class HelpCommandsClass(BaseEditCommandsClass):
     #@+node:ekr.20150514063305.392: *3* helpForDynamicAbbreviations
     @cmd('help-for-dynamic-abbreviations')
     def helpForDynamicAbbreviations(self, event=None):
-        '''Prints a discussion of abbreviations.'''
+        """Prints a discussion of abbreviations."""
         #@+<< define s >>
         #@+node:ekr.20150514063305.393: *4* << define s >> (helpForDynamicAbbreviations)
         #@@language rest
@@ -697,7 +697,7 @@ class HelpCommandsClass(BaseEditCommandsClass):
     #@+node:ekr.20150514063305.394: *3* helpForFindCommands
     @cmd('help-for-find-commands')
     def helpForFindCommands(self, event=None):
-        '''Prints a discussion of of Leo's find commands.'''
+        """Prints a discussion of of Leo's find commands."""
         #@+<< define s >>
         #@+node:ekr.20150514063305.395: *4* << define s >> (help-for-find-commands)
         #@@language rest
@@ -756,7 +756,7 @@ class HelpCommandsClass(BaseEditCommandsClass):
     #@+node:ekr.20150628161341.1: *3* helpForKeystroke
     @cmd('help-for-keystroke')
     def helpForKeystroke(self, event):
-        '''Prompts for any key and prints the bindings for that key.'''
+        """Prompts for any key and prints the bindings for that key."""
         c, k = self.c, self.c.k
         state_name = 'help-for-keystroke'
         state = k.getState(state_name)
@@ -768,17 +768,17 @@ class HelpCommandsClass(BaseEditCommandsClass):
             d = k.bindingsDict
             k.clearState()
             result = []
-            for bi in d.get(event.stroke, []): # a list of BindingInfo objects.
+            for bi in d.get(event.stroke, []):  # a list of BindingInfo objects.
                 pane, cmd = bi.pane, bi.commandName
-                result.append(cmd if pane == 'all' else '%s: %s' % (pane, cmd))
-            s = '%s: %s' % (event.stroke.s, ','.join(result))
+                result.append(cmd if pane == 'all' else f"{pane}: {cmd}")
+            s = f"{event.stroke.s}: {','.join(result)}"
             k.showStateAndMode()
             c.frame.putStatusLine(s, bg='blue', fg='white')
             c.bodyWantsFocus()
     #@+node:ekr.20150514063305.396: *3* helpForMinibuffer
     @cmd('help-for-minibuffer')
     def helpForMinibuffer(self, event=None):
-        '''Print a messages telling you how to get started with Leo.'''
+        """Print a messages telling you how to get started with Leo."""
         # A bug in Leo: triple quotes puts indentation before each line.
         c = self.c
         #@+<< define s >>
@@ -815,7 +815,7 @@ class HelpCommandsClass(BaseEditCommandsClass):
     #@+node:ekr.20150514063305.398: *3* helpForRegularExpressions
     @cmd('help-for-regular-expressions')
     def helpForRegularExpressions(self, event=None):
-        '''Prints a discussion of of Leo's find commands.'''
+        """Prints a discussion of of Leo's find commands."""
         #@+<< define s >>
         #@+node:ekr.20150514063305.399: *4* << define s >> (helpForRegularExpressions)
         #@@language rest
@@ -848,7 +848,7 @@ class HelpCommandsClass(BaseEditCommandsClass):
             \\              Matches a literal '\'.
             |               Specifies alternative: 'foo|bar' matches 'foo' or 'bar'.
             (...)           Matches any RE inside (), and delimits a group.
-            (?:...)         Mathces RE inside (), but doesn't delimit a group.
+            (?:...)         Matches RE inside (), but doesn't delimit a group.
             (?P<name>...)   Matches any RE inside (), and delimits a named group.
                             r'(?P<id>[a-zA-Z_]\w*)' defines a group named id.
             (?P=name)       Matches whatever text was matched by the earlier group named name.
@@ -886,7 +886,7 @@ class HelpCommandsClass(BaseEditCommandsClass):
     #@+node:ekr.20150514063305.400: *3* helpForScripting
     @cmd('help-for-scripting')
     def helpForScripting(self, event=None):
-        '''Prints a discussion of Leo scripting.'''
+        """Prints a discussion of Leo scripting."""
         #@+<< define s >>
         #@+node:ekr.20150514063305.401: *4* << define s >> (helpForScripting)
         #@@language rest
@@ -925,10 +925,6 @@ class HelpCommandsClass(BaseEditCommandsClass):
             g: The leo.core.leoGlobals module.
             p: The presently selected position, c.p.
 
-        @test scripts predefine all the above, plus::
-
-            self: The instance of unittest.TestCase
-
         Commands class
         ==============
 
@@ -950,7 +946,7 @@ class HelpCommandsClass(BaseEditCommandsClass):
             c.frame.iconBar         The icon bar.
             c.frame.log             The log pane.
             c.frame.log.widget      The gui widget for the log pane.
-            c.frame.log.wrapper     The high-level inteface for the log pane.
+            c.frame.log.wrapper     The high-level interface for the log pane.
             c.frame.tree            The tree pane.
 
         VNode class
@@ -968,7 +964,7 @@ class HelpCommandsClass(BaseEditCommandsClass):
         to associate persistent data with vnodes. For details see the section about
         userAttributes in the Customizing Leo chapter.
 
-        position class
+        Position class
         ==============
 
         A position represents the state of a traversal of an outline.
@@ -1031,8 +1027,7 @@ class HelpCommandsClass(BaseEditCommandsClass):
             p.moveToFirstChildOf(parent,n)
             p.moveToLastChildOf(parent,n)
             p.moveToNthChildOf(parent,n)
-            p.moveToRoot(oldRoot=None)
-                # oldRoot **must** be the old root position if it exists.
+            p.moveToRoot()
 
         The following position methods move positions *themselves*: they change the
         node to which a position refers. They do *not* change outline structure in
@@ -1107,7 +1102,7 @@ class HelpCommandsClass(BaseEditCommandsClass):
     #@+node:ekr.20170823084423.1: *3* helpForSettings
     @cmd('help-for-settings')
     def helpForSettings(self, event=None):
-        '''Prints a discussion of of Leo's find commands.'''
+        """Prints a discussion of of Leo's find commands."""
         #@+<< define s >>
         #@+node:ekr.20170823084456.1: *4* << define s >> (helpForSettings)
         #@@language rest
@@ -1126,17 +1121,17 @@ class HelpCommandsClass(BaseEditCommandsClass):
 
         leoSettings.leo is Leo's main settings file. myLeoSettings.leo contains
         your personal settings. Settings in myLeoSettings.leo override the settings
-        in leoSettings.leo. Put myLeoSettigns.leo in your home `~` directory or in
+        in leoSettings.leo. Put myLeoSettings.leo in your home `~` directory or in
         the `~/.leo` directory. Any other .leo file may contain an \@settings tree.
         Such settings apply only to that file.
 
         '''
         #@-<< define s >>
         self.c.putHelpFor(s)
-    #@+node:ekr.20150514063305.402: *3* printSettings
+    #@+node:ekr.20150514063305.402: *3* help.showSettings
     @cmd('show-settings')
-    def printSettings(self, event=None):
-        '''
+    def showSettings(self, event=None):
+        """
         Prints the value of every setting, except key bindings and commands and
         open-with tables. The following shows where the active setting came
         from:
@@ -1146,12 +1141,25 @@ class HelpCommandsClass(BaseEditCommandsClass):
         - [D] default settings.
         - [F] indicates the file being loaded,
         - [M] myLeoSettings.leo,
-        '''
+        - [T] theme .leo file.
+        """
         self.c.config.printSettings()
+    #@+node:ekr.20190831025811.1: *3* help.showSettingsOutline (new: #852)
+    @cmd('show-settings-outline')
+    def showSettingsOutline(self, event=None):
+        """
+        Create and open an outline, summarizing all presently active settings.
+
+        The outline retains the organization of all active settings files.
+
+        See #852: https://github.com/leo-editor/leo-editor/issues/852
+        """
+
+        self.c.config.createActivesSettingsOutline()
     #@+node:ekr.20150514063305.403: *3* pythonHelp
     @cmd('help-for-python')
     def pythonHelp(self, event=None):
-        '''Prompt for a arg for Python's help function, and put it to the log pane.'''
+        """Prompt for a arg for Python's help function, and put it to the VR pane."""
         c, k = self.c, self.c.k
         c.minibufferWantsFocus()
         k.setLabelBlue('Python help: ')
@@ -1162,18 +1170,23 @@ class HelpCommandsClass(BaseEditCommandsClass):
         k.clearState()
         k.resetLabel()
         s = k.arg.strip()
-        if s:
-            # Capture the output of Python's help command.
-            old = sys.stdout
-            try:
-                sys.stdout = stdout = g.FileLikeObject()
-                help(str(s))
-                s2 = stdout.read()
-            finally:
-                sys.stdout = old
-            # Send it to the vr pane as a <pre> block
-            s2 = '<pre>' + s2 + '</pre>'
-            c.putHelpFor(s2)
+        if not s:
+            return ''
+        old = sys.stdout
+        try:
+            sys.stdout = io.StringIO()
+            #  If the argument is a string, the string is looked up as a name...
+            # and a help page is printed on the console.
+            help(str(s))
+            s2 = sys.stdout.getvalue()  # #2165
+        finally:
+            sys.stdout = old
+        if not s2:
+            return ''
+        # Send it to the vr pane as a <pre> block
+        s2 = '<pre>' + s2 + '</pre>'
+        c.putHelpFor(s2)
+        return s2  # For unit tests.
     #@-others
 #@-others
 #@-leo
