@@ -1,28 +1,18 @@
 #@+leo-ver=5-thin
 #@+node:ekr.20100208065621.5894: * @file leoCache.py
-'''A module encapsulating Leo's file caching'''
+"""A module encapsulating Leo's file caching"""
 #@+<< imports >>
 #@+node:ekr.20100208223942.10436: ** << imports >> (leoCache)
-import sys
-isPython3 = sys.version_info >= (3, 0, 0)
-import leo.core.leoGlobals as g
-if isPython3:
-    import pickle
-else:
-    import cPickle as pickle
-# import glob
 import fnmatch
-# import hashlib
 import os
-import stat
-# import time
-import zlib
+import pickle
 import sqlite3
-# try:
-    # import marshal
-# except ImportError:
-    # marshal = None
+import stat
+from typing import Any, Dict, Sequence
+import zlib
+from leo.core import leoGlobals as g
 #@-<< imports >>
+# pylint: disable=raise-missing-from
 # Abbreviations used throughout.
 abspath = g.os_path_abspath
 basename = g.os_path_basename
@@ -32,91 +22,92 @@ isfile = g.os_path_isfile
 join = g.os_path_join
 normcase = g.os_path_normcase
 split = g.os_path_split
-SQLITE = True
 #@+others
 #@+node:ekr.20100208062523.5885: ** class CommanderCacher
-class CommanderCacher(object):
-    '''A class to manage per-commander caches.'''
+class CommanderCacher:
+    """A class to manage per-commander caches."""
 
     def __init__(self):
         try:
             path = join(g.app.homeLeoDir, 'db', 'global_data')
-            self.db = SqlitePickleShare(path) if SQLITE else PickleShareDB(path)
+            self.db = SqlitePickleShare(path)
         except Exception:
-            self.db = {}
-
+            self.db = {}  # type:ignore
     #@+others
     #@+node:ekr.20100209160132.5759: *3* cacher.clear
     def clear(self):
-        '''Clear the cache for all commanders.'''
+        """Clear the cache for all commanders."""
         # Careful: self.db may be a Python dict.
         try:
             self.db.clear()
         except Exception:
             g.trace('unexpected exception')
             g.es_exception()
-            self.db = {}
+            self.db = {}  # type:ignore
     #@+node:ekr.20180627062431.1: *3* cacher.close
     def close(self):
         # Careful: self.db may be a dict.
-        if SQLITE and hasattr(self.db, 'conn'):
+        if hasattr(self.db, 'conn'):
             # pylint: disable=no-member
             self.db.conn.commit()
             self.db.conn.close()
     #@+node:ekr.20180627042809.1: *3* cacher.commit
     def commit(self):
         # Careful: self.db may be a dict.
-        if SQLITE and hasattr(self.db, 'conn'):
+        if hasattr(self.db, 'conn'):
             # pylint: disable=no-member
             self.db.conn.commit()
     #@+node:ekr.20180611054447.1: *3* cacher.dump
     def dump(self):
-        '''Dump the indicated cache if --trace-cache is in effect.'''
+        """Dump the indicated cache if --trace-cache is in effect."""
         dump_cache(g.app.commander_db, tag='Commander Cache')
     #@+node:ekr.20180627053508.1: *3* cacher.get_wrapper
     def get_wrapper(self, c, fn=None):
-        '''Return a new wrapper for c.'''
+        """Return a new wrapper for c."""
         return CommanderWrapper(c, fn=fn)
     #@+node:ekr.20100208065621.5890: *3* cacher.test
     def test(self):
-        
+
         # pylint: disable=no-member
         if g.app.gui.guiName() == 'nullGui':
             # Null gui's don't normally set the g.app.gui.db.
             g.app.setGlobalDb()
         # Fixes bug 670108.
-        assert g.app.db is not None
-            # a PickleShareDB instance.
+        assert g.app.db is not None  # a PickleShareDB instance.
         # Make sure g.guessExternalEditor works.
         g.app.db.get("LEO_EDITOR")
-        self.initFileDB('~/testpickleshare')
+        # self.initFileDB('~/testpickleshare')
         db = self.db
         db.clear()
         assert not list(db.items())
         db['hello'] = 15
         db['aku ankka'] = [1, 2, 313]
         db['paths/nest/ok/keyname'] = [1, (5, 46)]
-        db.uncache() # frees memory, causes re-reads later
-        if 0: print(db.keys())
+        db.uncache()  # frees memory, causes re-reads later
+        # print(db.keys())
         db.clear()
         return True
     #@+node:ekr.20100210163813.5747: *3* cacher.save
-    def save(self, c, fn, changeName):
-        '''
+    def save(self, c, fn):
+        """
         Save the per-commander cache.
-        
+
         Change the cache prefix if changeName is True.
-        
+
         save and save-as set changeName to True, save-to does not.
-        '''
-        if SQLITE:
-            self.commit()
-        if changeName:
-            c.db = self.get_wrapper(c, fn=fn)
+        """
+        self.commit()
+        if fn:
+            # 1484: Change only the key!
+            if isinstance(c.db, CommanderWrapper):
+                c.db.key = fn
+                self.commit()
+            else:
+                g.trace('can not happen', c.db.__class__.__name__)
     #@-others
 #@+node:ekr.20180627052459.1: ** class CommanderWrapper
-class CommanderWrapper(object):
-    '''A class to distinguish keys from separate commanders.'''
+class CommanderWrapper:
+    """A class to distinguish keys from separate commanders."""
 
     def __init__(self, c, fn=None):
         self.c = c
@@ -125,68 +116,81 @@ class CommanderWrapper(object):
         self.user_keys = set()
 
     def get(self, key, default=None):
-        value = self.db.get('%s:::%s' % (self.key, key))
+        value = self.db.get(f"{self.key}:::{key}")
         return default if value is None else value
-    
+
     def keys(self):
         return sorted(list(self.user_keys))
-        
-    def __contains__ (self, key):
-        return '%s:::%s' % (self.key, key) in self.db
-    
-    def __delitem__ (self, key):
+
+    def __contains__(self, key):
+        return f"{self.key}:::{key}" in self.db
+
+    def __delitem__(self, key):
         if key in self.user_keys:
             self.user_keys.remove(key)
-        del self.db ['%s:::%s' % (self.key, key)]
-    
+        del self.db[f"{self.key}:::{key}"]
+
     def __getitem__(self, key):
-        return self.db ['%s:::%s' % (self.key, key)]
-            # May (properly) raise KeyError
-    
-    def __setitem__ (self, key, value):
+        return self.db[f"{self.key}:::{key}"]  # May (properly) raise KeyError
+
+    def __setitem__(self, key, value):
         self.user_keys.add(key)
-        self.db ['%s:::%s' % (self.key, key)] = value
+        self.db[f"{self.key}:::{key}"] = value
 #@+node:ekr.20180627041556.1: ** class GlobalCacher
-class GlobalCacher(object):
-    '''A singleton global cacher, g.app.db'''
-    
+class GlobalCacher:
+    """A singleton global cacher, g.app.db"""
+
     def __init__(self):
-        '''Ctor for the GlobalCacher class.'''
+        """Ctor for the GlobalCacher class."""
+        trace = 'cache' in g.app.debug
         try:
             path = join(g.app.homeLeoDir, 'db', 'g_app_db')
-            self.db = SqlitePickleShare(path) if SQLITE else PickleShareDB(path)
+            if trace:
+                print('path for g.app.db:', repr(path))
+            self.db = SqlitePickleShare(path)
+            if trace and self.db is not None:
+                self.dump(tag='Startup')
         except Exception:
-            self.db = {} # Use a plain dict as a dummy.
-
+            if trace:
+                g.es_exception()
+            # Use a plain dict as a dummy.
+            self.db = {}  # type:ignore
     #@+others
     #@+node:ekr.20180627045750.1: *3* g_cacher.clear
     def clear(self):
-        '''Clear the global cache.'''
+        """Clear the global cache."""
         # Careful: self.db may be a Python dict.
+        if 'cache' in g.app.debug:
+            g.trace('clear g.app.db')
         try:
-            self.db.clear(verbose=True)
+            self.db.clear()
         except TypeError:
             self.db.clear()
         except Exception:
             g.trace('unexpected exception')
             g.es_exception()
-            self.db = {}
+            self.db = {}  # type:ignore
     #@+node:ekr.20180627042948.1: *3* g_cacher.commit_and_close()
     def commit_and_close(self):
         # Careful: self.db may be a dict.
-        if SQLITE and hasattr(self.db, 'conn'):
+        if hasattr(self.db, 'conn'):
             # pylint: disable=no-member
+            if 'cache' in g.app.debug:
+                self.dump(tag='Shutdown')
             self.db.conn.commit()
             self.db.conn.close()
     #@+node:ekr.20180627045953.1: *3* g_cacher.dump
-    def dump(self):
-        '''Dump the indicated cache if --trace-cache is in effect.'''
-        dump_cache(g.app.db, 'Global Cache')
+    def dump(self, tag=''):
+        """Dump the indicated cache if --trace-cache is in effect."""
+        tag0 = 'Global Cache'
+        tag2 = f"{tag0}: {tag}" if tag else tag0
+        dump_cache(self.db, tag2)  # Careful: g.app.db may not be set yet.
     #@-others
 #@+node:ekr.20100208223942.5967: ** class PickleShareDB
 _sentinel = object()
 
-class PickleShareDB(object):
+
+class PickleShareDB:
     """ The main 'connection' object for PickleShare database """
     #@+others
     #@+node:ekr.20100208223942.5968: *3*  Birth & special methods
@@ -199,12 +203,13 @@ class PickleShareDB(object):
         self.root = abspath(expanduser(root))
         if not isdir(self.root) and not g.unitTesting:
             self._makedirs(self.root)
+        # Keys are normalized file names.
+        # Values are tuples (obj, orig_mod_time)
         self.cache = {}
-            # Keys are normalized file names.
-            # Values are tuples (obj, orig_mod_time)
 
         def loadz(fileobj):
             if fileobj:
+                # Retain this code for maximum compatibility.
                 try:
                     val = pickle.loads(
                         zlib.decompress(fileobj.read()))
@@ -212,16 +217,15 @@ class PickleShareDB(object):
                     g.es("Unpickling error - Python 3 data accessed from Python 2?")
                     return None
                 return val
-            else:
-                return None
+            return None
 
         def dumpz(val, fileobj):
             if fileobj:
                 try:
-                    # use Python 2's highest protocol, 2, if possible
+                    # Use Python 2's highest protocol, 2, if possible
                     data = pickle.dumps(val, 2)
                 except Exception:
-                    # but use best available if that doesn't work (unlikely)
+                    # Use best available if that doesn't work (unlikely)
                     data = pickle.dumps(val, pickle.HIGHEST_PROTOCOL)
                 compressed = zlib.compress(data)
                 fileobj.write(compressed)
@@ -231,7 +235,7 @@ class PickleShareDB(object):
     #@+node:ekr.20100208223942.5970: *4* __contains__(PickleShareDB)
     def __contains__(self, key):
 
-        return self.has_key(key) # NOQA
+        return self.has_key(key)  # NOQA
     #@+node:ekr.20100208223942.5971: *4* __delitem__
     def __delitem__(self, key):
         """ del db["key"] """
@@ -268,7 +272,7 @@ class PickleShareDB(object):
             yield k
     #@+node:ekr.20100208223942.5974: *4* __repr__
     def __repr__(self):
-        return "PickleShareDB('%s')" % self.root
+        return f"PickleShareDB('{self.root}')"
     #@+node:ekr.20100208223942.5975: *4* __setitem__ (PickleShareDB)
     def __setitem__(self, key, value):
         """ db['key'] = 5 """
@@ -412,9 +416,8 @@ class PickleShareDB(object):
         segments += dest_list[i:]
         if segments:
             return join(*segments)
-        else:
-            # If they happen to be identical, use os.curdir.
-            return os.curdir
+        # If they happen to be identical, use os.curdir.
+        return os.curdir
     #@+node:ekr.20100208223942.10462: *4* _splitall
     # Used by relpathto.
 
@@ -456,7 +459,8 @@ class PickleShareDB(object):
 #@+node:vitalije.20170716201700.1: ** class SqlitePickleShare
 _sentinel = object()
 
-class SqlitePickleShare(object):
+
+class SqlitePickleShare:
     """ The main 'connection' object for SqlitePickleShare database """
     #@+others
     #@+node:vitalije.20170716201700.2: *3*  Birth & special methods
@@ -475,53 +479,53 @@ class SqlitePickleShare(object):
         dbfile = ':memory:' if g.unitTesting else join(root, 'cache.sqlite')
         self.conn = sqlite3.connect(dbfile, isolation_level=None)
         self.init_dbtables(self.conn)
+        # Keys are normalized file names.
+        # Values are tuples (obj, orig_mod_time)
         self.cache = {}
-            # Keys are normalized file names.
-            # Values are tuples (obj, orig_mod_time)
 
         def loadz(data):
             if data:
+                # Retain this code for maximum compatibility.
                 try:
                     val = pickle.loads(zlib.decompress(data))
-                except (ValueError, TypeError):
+                except(ValueError, TypeError):
                     g.es("Unpickling error - Python 3 data accessed from Python 2?")
                     return None
                 return val
-            else:
-                return None
+            return None
 
         def dumpz(val):
             try:
-                # use Python 2's highest protocol, 2, if possible
+                # Use Python 2's highest protocol, 2, if possible
                 data = pickle.dumps(val, protocol=2)
             except Exception:
-                # but use best available if that doesn't work (unlikely)
+                # Use best available if that doesn't work (unlikely)
                 data = pickle.dumps(val, pickle.HIGHEST_PROTOCOL)
             return sqlite3.Binary(zlib.compress(data))
 
         self.loader = loadz
         self.dumper = dumpz
-        if g.isPython3:
-            self.reset_protocol_in_values()
+        self.reset_protocol_in_values()
     #@+node:vitalije.20170716201700.4: *4* __contains__(SqlitePickleShare)
     def __contains__(self, key):
 
-        return self.has_key(key) # NOQA
+        return self.has_key(key)  # NOQA
     #@+node:vitalije.20170716201700.5: *4* __delitem__
     def __delitem__(self, key):
         """ del db["key"] """
         try:
-            self.conn.execute('''delete from cachevalues
+            self.conn.execute(
+                '''delete from cachevalues
                 where key=?''', (key,))
         except sqlite3.OperationalError:
             pass
-
     #@+node:vitalije.20170716201700.6: *4* __getitem__
     def __getitem__(self, key):
         """ db['key'] reading """
         try:
             obj = None
-            for row in self.conn.execute('''select data from cachevalues
+            for row in self.conn.execute(
+                '''select data from cachevalues
                 where key=?''', (key,)):
                 obj = self.loader(row[0])
                 break
@@ -537,17 +541,17 @@ class SqlitePickleShare(object):
             yield k
     #@+node:vitalije.20170716201700.8: *4* __repr__
     def __repr__(self):
-        return "SqlitePickleShare('%s')" % self.root
+        return f"SqlitePickleShare('{self.root}')"
     #@+node:vitalije.20170716201700.9: *4* __setitem__
     def __setitem__(self, key, value):
         """ db['key'] = 5 """
         try:
             data = self.dumper(value)
-            self.conn.execute('''replace into cachevalues(key, data)
-                values(?,?);''', (key, data))
-        except sqlite3.OperationalError as e:
-            g.es_exception(e)
-
+            self.conn.execute(
+                '''replace into cachevalues(key, data) values(?,?);''',
+                (key, data))
+        except sqlite3.OperationalError:
+            g.es_exception()
     #@+node:vitalije.20170716201700.10: *3* _makedirs
     def _makedirs(self, fn, mode=0o777):
 
@@ -572,7 +576,6 @@ class SqlitePickleShare(object):
         mydir.walkfiles('*.tmp') yields only files with the .tmp
         extension.
         """
-        
     #@+node:vitalije.20170716201700.13: *4* _listdir
     def _listdir(self, s, pattern=None):
         """ D.listdir() -> List of items in this directory.
@@ -602,7 +605,7 @@ class SqlitePickleShare(object):
         # It would be more thorough to delete everything
         # below the root directory, but it's not necessary.
         self.conn.execute('delete from cachevalues;')
-    #@+node:vitalije.20170716201700.16: *3* get
+    #@+node:vitalije.20170716201700.16: *3* get  (SqlitePickleShare)
     def get(self, key, default=None):
 
         if not self.has_key(key):
@@ -610,7 +613,7 @@ class SqlitePickleShare(object):
         try:
             val = self[key]
             return val
-        except KeyError:
+        except Exception:  # #1444: Was KeyError.
             return default
     #@+node:vitalije.20170716201700.17: *3* has_key (SqlightPickleShare)
     def has_key(self, key):
@@ -621,7 +624,7 @@ class SqlitePickleShare(object):
     #@+node:vitalije.20170716201700.18: *3* items
     def items(self):
         sql = 'select key,data from cachevalues;'
-        for key,data in self.conn.execute(sql):
+        for key, data in self.conn.execute(sql):
             yield key, data
     #@+node:vitalije.20170716201700.19: *3* keys
     # Called by clear, and during unit testing.
@@ -630,7 +633,7 @@ class SqlitePickleShare(object):
         """Return all keys in DB, or all keys matching a glob"""
         if globpat is None:
             sql = 'select key from cachevalues;'
-            args = tuple()
+            args: Sequence[Any] = tuple()
         else:
             sql = "select key from cachevalues where key glob ?;"
             # pylint: disable=trailing-comma-tuple
@@ -640,7 +643,8 @@ class SqlitePickleShare(object):
     #@+node:vitalije.20170818091008.1: *3* reset_protocol_in_values
     def reset_protocol_in_values(self):
         PROTOCOLKEY = '__cache_pickle_protocol__'
-        if self.get(PROTOCOLKEY, 3) == 2: return
+        if self.get(PROTOCOLKEY, 3) == 2:
+            return
         #@+others
         #@+node:vitalije.20170818115606.1: *4* viewrendered special case
         import json
@@ -656,7 +660,6 @@ class SqlitePickleShare(object):
                 return itms[-1][1]
             return None
         #@-others
-
         self.conn.isolation_level = 'DEFERRED'
 
         sql0 = '''select key, data from cachevalues order by key limit 50'''
@@ -678,10 +681,13 @@ class SqlitePickleShare(object):
     #@-others
 #@+node:ekr.20180627050237.1: ** function: dump_cache
 def dump_cache(db, tag):
-    '''Dump the given cache.'''
-    print('\n===== %s =====\n' % tag)
+    """Dump the given cache."""
+    print(f'\n===== {tag} =====\n')
+    if db is None:
+        print('db is None!')
+        return
     # Create a dict, sorted by file prefixes.
-    d = {}
+    d: Dict[str, Any] = {}
     for key in db.keys():
         key = key[0]
         val = db.get(key)
@@ -700,30 +706,33 @@ def dump_cache(db, tag):
             dump_list('File: ' + key, d.get(key))
             files += 1
     if d.get('None'):
-        heading = 'All others' if files else None
+        heading = f"All others ({tag})" if files else None
         dump_list(heading, d.get('None'))
-        
+
 def dump_list(heading, aList):
     if heading:
-        print('\n%s...\n' % heading)
+        print(f'\n{heading}...\n')
     for aTuple in aList:
         key, val = aTuple
-        if g.isString(val):
-            if key.endswith(('leo_expanded', 'leo_marked')):
+        if isinstance(val, str):
+            if key.startswith('windowState'):
+                print(key)
+            elif key.endswith(('leo_expanded', 'leo_marked')):
                 if val:
-                    print('%30s:' % key)
+                    print(f"{key:30}:")
                     g.printObj(val.split(','))
                 else:
-                    print('%30s: []' % key)
+                    print(f"{key:30}: []")
             else:
-                print('%30s: %s' % (key, val))   
+                print(f"{key:30}: {val}")
         elif isinstance(val, (int, float)):
-            print('%30s: %s' % (key, val))    
+            print(f"{key:30}: {val}")
         else:
-            print('%30s:' % key)
+            print(f"{key:30}:")
             g.printObj(val)
 #@-others
 #@@language python
 #@@tabwidth -4
 #@@pagewidth 70
+
 #@-leo
