@@ -1,13 +1,13 @@
 #@+leo-ver=5-thin
 #@+node:ekr.20180212072657.2: * @file leoCompare.py
 """Leo's base compare class."""
-import leo.core.leoGlobals as g
 import difflib
 import filecmp
 import os
+from leo.core import leoGlobals as g
 #@+others
 #@+node:ekr.20031218072017.3633: ** class LeoCompare
-class BaseLeoCompare(object):
+class BaseLeoCompare:
     """The base class for Leo's compare code."""
     #@+others
     #@+node:ekr.20031218072017.3634: *3* compare.__init__
@@ -23,8 +23,8 @@ class BaseLeoCompare(object):
         ignoreInteriorWhitespace=False,
         ignoreLeadingWhitespace=True,
         ignoreSentinelLines=False,
-        limitCount=0, # Zero means don't stop.
-        limitToExtension=".py", # For directory compares.
+        limitCount=0,  # Zero means don't stop.
+        limitToExtension=".py",  # For directory compares.
         makeWhitespaceVisible=True,
         printBothMatches=False,
         printMatches=False,
@@ -76,7 +76,8 @@ class BaseLeoCompare(object):
         if self.outputFileName:
             self.openOutputFile()
         ok = self.outputFileName is None or self.outputFile
-        if not ok: return None
+        if not ok:
+            return None
         # Create files and files2, the lists of files to be compared.
         files1 = []
         files2 = []
@@ -95,7 +96,7 @@ class BaseLeoCompare(object):
             else:
                 files2.append(f)
         # Compare the files and set the yes, no and missing lists.
-        yes = []; no = []; missing1 = []; missing2 = []
+        missing1, missing2, no, yes = [], [], [], []
         for f1 in files1:
             head, f2 = g.os_path_split(f1)
             if f2 in files2:
@@ -103,8 +104,10 @@ class BaseLeoCompare(object):
                     name1 = g.os_path_join(dir1, f1)
                     name2 = g.os_path_join(dir2, f2)
                     val = filecmp.cmp(name1, name2, 0)
-                    if val: yes.append(f1)
-                    else: no.append(f1)
+                    if val:
+                        yes.append(f1)
+                    else:
+                        no.append(f1)
                 except Exception:
                     self.show("exception in filecmp.cmp")
                     g.es_exception()
@@ -128,7 +131,7 @@ class BaseLeoCompare(object):
         if self.outputFile:
             self.outputFile.close()
             self.outputFile = None
-        return None # To keep pychecker happy.
+        return None  # To keep pychecker happy.
     #@+node:ekr.20031218072017.3636: *3* compare_files (entry)
     def compare_files(self, name1, name2):
         if name1 == name2:
@@ -137,7 +140,7 @@ class BaseLeoCompare(object):
         self.compare_two_files(name1, name2)
     #@+node:ekr.20180211123531.1: *3* compare_list_of_files (entry for scripts)
     def compare_list_of_files(self, aList1):
-        
+
         aList = list(set(aList1))
         while len(aList) > 1:
             path1 = aList[0]
@@ -146,7 +149,7 @@ class BaseLeoCompare(object):
                 self.compare_two_files(path1, path2)
     #@+node:ekr.20180211123741.1: *3* compare_two_files
     def compare_two_files(self, name1, name2):
-        '''A helper function.'''
+        """A helper function."""
         f1 = f2 = None
         try:
             f1 = self.doOpen(name1)
@@ -162,10 +165,13 @@ class BaseLeoCompare(object):
             self.show("exception comparing files")
             g.es_exception()
         try:
-            if f1: f1.close()
-            if f2: f2.close()
+            if f1:
+                f1.close()
+            if f2:
+                f2.close()
             if self.outputFile:
-                self.outputFile.close(); self.outputFile = None
+                self.outputFile.close()
+                self.outputFile = None
         except Exception:
             self.show("exception closing files")
             g.es_exception()
@@ -177,8 +183,8 @@ class BaseLeoCompare(object):
         if self.ignoreInteriorWhitespace:
             k1 = g.skip_ws(s1, 0)
             k2 = g.skip_ws(s2, 0)
-            ws1 = s1[: k1]
-            ws2 = s2[: k2]
+            ws1 = s1[:k1]
+            ws2 = s2[:k2]
             tail1 = s1[k1:]
             tail2 = s2[k2:]
             tail1 = tail1.replace(" ", "").replace("\t", "")
@@ -189,7 +195,10 @@ class BaseLeoCompare(object):
     #@+node:ekr.20031218072017.3638: *3* compare_open_files
     def compare_open_files(self, f1, f2, name1, name2):
         # self.show("compare_open_files")
-        lines1 = 0; lines2 = 0; mismatches = 0; printTrailing = True
+        lines1 = 0
+        lines2 = 0
+        mismatches = 0
+        printTrailing = True
         sentinelComment1 = sentinelComment2 = None
         if self.openOutputFile():
             self.show("1: " + name1)
@@ -199,47 +208,66 @@ class BaseLeoCompare(object):
         #@+<< handle opening lines >>
         #@+node:ekr.20031218072017.3639: *4* << handle opening lines >>
         if self.ignoreSentinelLines:
-            s1 = g.readlineForceUnixNewline(f1); lines1 += 1
-            s2 = g.readlineForceUnixNewline(f2); lines2 += 1
+            s1 = g.readlineForceUnixNewline(f1)
+            lines1 += 1
+            s2 = g.readlineForceUnixNewline(f2)
+            lines2 += 1
             # Note: isLeoHeader may return None.
             sentinelComment1 = self.isLeoHeader(s1)
             sentinelComment2 = self.isLeoHeader(s2)
-            if not sentinelComment1: self.show("no @+leo line for " + name1)
-            if not sentinelComment2: self.show("no @+leo line for " + name2)
+            if not sentinelComment1:
+                self.show("no @+leo line for " + name1)
+            if not sentinelComment2:
+                self.show("no @+leo line for " + name2)
         if self.ignoreFirstLine1:
             if s1 is None:
-                g.readlineForceUnixNewline(f1); lines1 += 1
+                g.readlineForceUnixNewline(f1)
+                lines1 += 1
             s1 = None
         if self.ignoreFirstLine2:
             if s2 is None:
-                g.readlineForceUnixNewline(f2); lines2 += 1
+                g.readlineForceUnixNewline(f2)
+                lines2 += 1
             s2 = None
         #@-<< handle opening lines >>
         while 1:
             if s1 is None:
-                s1 = g.readlineForceUnixNewline(f1); lines1 += 1
+                s1 = g.readlineForceUnixNewline(f1)
+                lines1 += 1
             if s2 is None:
-                s2 = g.readlineForceUnixNewline(f2); lines2 += 1
+                s2 = g.readlineForceUnixNewline(f2)
+                lines2 += 1
             #@+<< ignore blank lines and/or sentinels >>
             #@+node:ekr.20031218072017.3640: *4* << ignore blank lines and/or sentinels >>
             # Completely empty strings denotes end-of-file.
             if s1:
                 if self.ignoreBlankLines and s1.isspace():
-                    s1 = None; continue
-                if self.ignoreSentinelLines and sentinelComment1 and self.isSentinel(s1, sentinelComment1):
-                    s1 = None; continue
+                    s1 = None
+                    continue
+                if self.ignoreSentinelLines and sentinelComment1 and self.isSentinel(
+                    s1, sentinelComment1):
+                    s1 = None
+                    continue
             if s2:
                 if self.ignoreBlankLines and s2.isspace():
-                    s2 = None; continue
-                if self.ignoreSentinelLines and sentinelComment2 and self.isSentinel(s2, sentinelComment2):
-                    s2 = None; continue
+                    s2 = None
+                    continue
+                if self.ignoreSentinelLines and sentinelComment2 and self.isSentinel(
+                    s2, sentinelComment2):
+                    s2 = None
+                    continue
             #@-<< ignore blank lines and/or sentinels >>
-            n1 = len(s1); n2 = len(s2)
-            if n1 == 0 and n2 != 0: self.show("1.eof***:")
-            if n2 == 0 and n1 != 0: self.show("2.eof***:")
-            if n1 == 0 or n2 == 0: break
+            n1 = len(s1)
+            n2 = len(s2)
+            if n1 == 0 and n2 != 0:
+                self.show("1.eof***:")
+            if n2 == 0 and n1 != 0:
+                self.show("2.eof***:")
+            if n1 == 0 or n2 == 0:
+                break
             match = self.compare_lines(s1, s2)
-            if not match: mismatches += 1
+            if not match:
+                mismatches += 1
             #@+<< print matches and/or mismatches >>
             #@+node:ekr.20031218072017.3641: *4* << print matches and/or mismatches >>
             if self.limitCount == 0 or mismatches <= self.limitCount:
@@ -266,7 +294,7 @@ class BaseLeoCompare(object):
                     self.show("")
                     printTrailing = False
             #@-<< warn if mismatch limit reached >>
-            s1 = s2 = None # force a read of both lines.
+            s1 = s2 = None  # force a read of both lines.
         #@+<< handle reporting after at least one eof is seen >>
         #@+node:ekr.20031218072017.3643: *4* << handle reporting after at least one eof is seen >>
         if n1 > 0:
@@ -281,13 +309,10 @@ class BaseLeoCompare(object):
     #@+node:ekr.20031218072017.3644: *3* compare.filecmp
     def filecmp(self, f1, f2):
         val = filecmp.cmp(f1, f2)
-        if 1:
-            if val: self.show("equal")
-            else: self.show("*** not equal")
+        if val:
+            self.show("equal")
         else:
-            self.show("filecmp.cmp returns:")
-            if val: self.show(str(val) + " (equal)")
-            else: self.show(str(val) + " (not equal)")
+            self.show("*** not equal")
         return val
     #@+node:ekr.20031218072017.3645: *3* compare.utils...
     #@+node:ekr.20031218072017.3646: *4* compare.doOpen
@@ -300,22 +325,22 @@ class BaseLeoCompare(object):
             return None
     #@+node:ekr.20031218072017.3647: *4* compare.dump
     def dump(self, tag, s):
-        compare = self; out = tag
-        for ch in s[: -1]: # don't print the newline
+        compare = self
+        out = tag
+        for ch in s[:-1]:  # don't print the newline
             if compare.makeWhitespaceVisible:
                 if ch == '\t':
-                    out += "["; out += "t"; out += "]"
+                    out += "["
+                    out += "t"
+                    out += "]"
                 elif ch == ' ':
-                    out += "["; out += " "; out += "]"
-                else: out += ch
-            else:
-                if 1:
+                    out += "["
+                    out += " "
+                    out += "]"
+                else:
                     out += ch
-                else: # I don't know why I thought this was a good idea ;-)
-                    if ch == '\t' or ch == ' ':
-                        out += ' '
-                    else:
-                        out += ch
+            else:
+                out += ch
         self.show(out)
     #@+node:ekr.20031218072017.3648: *4* compare.dumpToEndOfFile
     def dumpToEndOfFile(self, tag, f, s, line, printTrailing):
@@ -345,9 +370,9 @@ class BaseLeoCompare(object):
         j = s.find(tag)
         if j > 0:
             i = g.skip_ws(s, 0)
-            if i < j: return s[i: j]
-            else: return None
-        else: return None
+            if i < j:
+                return s[i:j]
+        return None
 
     def isSentinel(self, s, sentinelComment):
         i = g.skip_ws(s, 0)
@@ -412,29 +437,28 @@ class BaseLeoCompare(object):
 class LeoCompare(BaseLeoCompare):
     """
     A class containing Leo's compare code.
-    
+
     These are not very useful comparisons.
     """
     pass
 #@+node:ekr.20180211170333.1: ** class CompareLeoOutlines
-class CompareLeoOutlines(object):
-    '''
+class CompareLeoOutlines:
+    """
     A class to do outline-oriented diffs of two or more .leo files.
     Similar to GitDiffController, adapted for use by scripts.
-    '''
-    
-    def __init__ (self, c):
-        '''Ctor for the LeoOutlineCompare class.'''
+    """
+
+    def __init__(self, c):
+        """Ctor for the LeoOutlineCompare class."""
         self.c = c
         self.file_node = None
         self.root = None
         self.path1 = None
         self.path2 = None
-
     #@+others
     #@+node:ekr.20180211170333.2: *3* loc.diff_list_of_files (entry)
     def diff_list_of_files(self, aList, visible=True):
-        '''The main entry point for scripts.'''
+        """The main entry point for scripts."""
         if len(aList) < 2:
             g.trace('Not enough files in', repr(aList))
             return
@@ -448,7 +472,7 @@ class CompareLeoOutlines(object):
         self.finish()
     #@+node:ekr.20180211170333.3: *3* loc.diff_two_files
     def diff_two_files(self, fn1, fn2):
-        '''Create an outline describing the git diffs for fn.'''
+        """Create an outline describing the git diffs for fn."""
         self.path1, self.path2 = fn1, fn2
         s1 = self.get_file(fn1)
         s2 = self.get_file(fn2)
@@ -462,16 +486,16 @@ class CompareLeoOutlines(object):
         c2 = self.open_outline(fn2)
         if c1 and c2:
             self.make_diff_outlines(c1, c2)
-            self.file_node.b = '%s\n@language %s\n' % (
-                self.file_node.b.rstrip(),
-                c2.target_language)
+            self.file_node.b = (
+                f"{self.file_node.b.rstrip()}\n"
+                f"@language {c2.target_language}\n")
     #@+node:ekr.20180211170333.4: *3* loc.Utils
     #@+node:ekr.20180211170333.5: *4* loc.compute_dicts
     def compute_dicts(self, c1, c2):
-        '''Compute inserted, deleted, changed dictionaries.'''
-        d1 = {v.fileIndex: v for v in c1.all_unique_nodes()} 
+        """Compute inserted, deleted, changed dictionaries."""
+        d1 = {v.fileIndex: v for v in c1.all_unique_nodes()}
         d2 = {v.fileIndex: v for v in c2.all_unique_nodes()}
-        added   = {key: d2.get(key) for key in d2 if not d1.get(key)}
+        added = {key: d2.get(key) for key in d2 if not d1.get(key)}
         deleted = {key: d1.get(key) for key in d1 if not d2.get(key)}
         changed = {}
         for key in d1:
@@ -485,7 +509,7 @@ class CompareLeoOutlines(object):
         return added, deleted, changed
     #@+node:ekr.20180211170333.6: *4* loc.create_compare_node
     def create_compare_node(self, c1, c2, d, kind):
-        '''Create nodes describing the changes.'''
+        """Create nodes describing the changes."""
         if not d:
             return
         parent = self.file_node.insertAsLastChild()
@@ -504,7 +528,7 @@ class CompareLeoOutlines(object):
                 ))
                 if ''.join(body).strip():
                     body.insert(0, '@language patch\n')
-                    body.append('@language %s\n' % (c2.target_language))
+                    body.append(f"@language {c2.target_language}\n")
                 else:
                     body = ['Only headline has changed']
                 organizer.b = ''.join(body)
@@ -524,47 +548,39 @@ class CompareLeoOutlines(object):
                 p.b = v.b
     #@+node:ekr.20180211170333.7: *4* loc.create_file_node
     def create_file_node(self, diff_list, fn1, fn2):
-        '''Create an organizer node for the file.'''
+        """Create an organizer node for the file."""
         p = self.root.insertAsLastChild()
-        p.h = '%s, %s' % (g.shortFileName(fn1).strip(), g.shortFileName(fn2).strip())
+        p.h = f"{g.shortFileName(fn1).strip()}, {g.shortFileName(fn2).strip()}"
         p.b = ''.join(diff_list)
         return p
     #@+node:ekr.20180211170333.8: *4* loc.create_root
     def create_root(self, aList):
-        '''Create the top-level organizer node describing all the diffs.'''
+        """Create the top-level organizer node describing all the diffs."""
         c = self.c
         p = c.lastTopLevel().insertAfter()
         p.h = 'diff-leo-files'
         p.b = '\n'.join(aList) + '\n'
         return p
-    #@+node:ekr.20180211170333.9: *4* loc.find_gnx (no longer used)
-    def find_gnx(self, c, gnx):
-        '''Return a position in c having the given gnx.'''
-        for p in c.all_unique_positions():
-            if p.v.fileIndex == gnx:
-                return p
-        return None
     #@+node:ekr.20180211170333.10: *4* loc.finish
     def finish(self):
-        '''Finish execution of this command.'''
+        """Finish execution of this command."""
         c = self.c
         if hasattr(g.app.gui, 'frameFactory'):
             tff = g.app.gui.frameFactory
             tff.setTabForCommander(c)
-        c.contractAllHeadlines(redrawFlag=False)
-        self.root.expand()
         c.selectPosition(self.root)
+        self.root.expand()
         c.bodyWantsFocus()
         c.redraw()
     #@+node:ekr.20180211170333.11: *4* loc.get_file
     def get_file(self, path):
-        '''Return the contents of the file whose path is given.'''
+        """Return the contents of the file whose path is given."""
         with open(path, 'rb') as f:
             s = f.read()
-        return g.toUnicode(s).replace('\r','')
+        return g.toUnicode(s).replace('\r', '')
     #@+node:ekr.20180211170333.13: *4* loc.make_diff_outlines
     def make_diff_outlines(self, c1, c2):
-        '''Create an outline-oriented diff from the outlines c1 and c2.'''
+        """Create an outline-oriented diff from the outlines c1 and c2."""
         added, deleted, changed = self.compute_dicts(c1, c2)
         table = (
             (added, 'Added'),
@@ -574,11 +590,11 @@ class CompareLeoOutlines(object):
             self.create_compare_node(c1, c2, d, kind)
     #@+node:ekr.20180211170333.14: *4* loc.open_outline
     def open_outline(self, fn):
-        '''
+        """
         Find the commander for fn, creating a new outline tab if necessary.
-        
+
         Using open commanders works because we always read entire .leo files.
-        '''
+        """
         for frame in g.app.windowList:
             if frame.c.fileName() == fn:
                 return frame.c
@@ -589,42 +605,42 @@ class CompareLeoOutlines(object):
 #@+node:ekr.20180213104556.1: *3* @g.command(diff-and-open-leo-files)
 @g.command('diff-and-open-leo-files')
 def diff_and_open_leo_files(event):
-    '''
+    """
     Open a dialog prompting for two or more .leo files.
-    
+
     Opens all the files and creates a top-level node in c's outline showing
     the diffs of those files, two at a time.
-    '''
+    """
     diff_leo_files_helper(event,
-        title = "Diff And Open Leo Files",
-        visible = True,
+        title="Diff And Open Leo Files",
+        visible=True,
     )
 #@+node:ekr.20180213040339.1: *3* @g.command(diff-leo-files)
 @g.command('diff-leo-files')
 def diff_leo_files(event):
-    '''
+    """
     Open a dialog prompting for two or more .leo files.
 
     Creates a top-level node showing the diffs of those files, two at a time.
-    '''
+    """
     diff_leo_files_helper(event,
-        title = "Diff Leo Files",
-        visible = False,
+        title="Diff Leo Files",
+        visible=False,
     )
 #@+node:ekr.20160331191740.1: *3* @g.command(diff-marked-nodes)
 @g.command('diff-marked-nodes')
 def diffMarkedNodes(event):
-    '''
+    """
     When two or more nodes are marked, this command does the following:
 
     - Creates a "diff marked node" as the last top-level node. The body of
       this node contains "diff n" nodes, one for each pair of compared
       nodes.
-      
+
     - Each diff n contains the diffs between the two diffed nodes, that is,
       difflib.Differ().compare(p1.b, p2.b).  The children of the diff n are
       *clones* of the two compared nodes.
-    '''
+    """
     c = event and event.get('c')
     if not c:
         return
@@ -639,12 +655,12 @@ def diffMarkedNodes(event):
             p1, p2 = aList[0], aList[1]
             aList = aList[1:]
             lines = difflib.Differ().compare(
-                g.splitLines(p1.b.rstrip()+'\n'),
-                g.splitLines(p2.b.rstrip()+'\n'))
+                g.splitLines(p1.b.rstrip() + '\n'),
+                g.splitLines(p2.b.rstrip() + '\n'))
             p = root.insertAsLastChild()
             # p.h = 'Compare: %s, %s' % (g.truncate(p1.h, 22), g.truncate(p2.h, 22))
-            p.h = 'diff %s' % n
-            p.b = '1: %s\n2: %s\n%s' % (p1.h, p2.h, ''.join(list(lines)))
+            p.h = f"diff {n}"
+            p.b = f"1: {p1.h}\n2: {p2.h}\n{''.join(list(lines))}"
             for p3 in (p1, p2):
                 clone = p3.clone()
                 clone.moveToLastChildOf(p)
@@ -654,10 +670,9 @@ def diffMarkedNodes(event):
         c.redraw()
     else:
         g.es_print('Please mark at least 2 nodes')
-
 #@+node:ekr.20180213104627.1: *3* diff_leo_files_helper
 def diff_leo_files_helper(event, title, visible):
-    '''Prompt for a list of .leo files to open.'''
+    """Prompt for a list of .leo files to open."""
     c = event and event.get('c')
     if not c:
         return
@@ -677,33 +692,6 @@ def diff_leo_files_helper(event, title, visible):
         CompareLeoOutlines(c).diff_list_of_files(paths, visible=visible)
     elif len(paths) == 1:
         g.es_print('Please pick two or more .leo files')
-#@+node:ekr.20031218072017.3632: *3* go
-def go():
-    compare = LeoCompare(
-        commands=None,
-        appendOutput=True,
-        ignoreBlankLines=True,
-        ignoreFirstLine1=False,
-        ignoreFirstLine2=False,
-        ignoreInteriorWhitespace=False,
-        ignoreLeadingWhitespace=True,
-        ignoreSentinelLines=False,
-        limitCount=9, # Zero means don't stop.
-        limitToExtension=".py", # For directory compares.
-        makeWhitespaceVisible=True,
-        printBothMatches=False,
-        printMatches=False,
-        printMismatches=True,
-        printTrailingMismatches=False,
-        outputFileName=None)
-    if 1: # Compare all files in Tangle test directories
-        path1 = "c:\\prog\\test\\tangleTest\\"
-        path2 = "c:\\prog\\test\\tangleTestCB\\"
-        compare.compare_directories(path1, path2)
-    else: # Compare two files.
-        name1 = "c:\\prog\\test\\compare1.txt"
-        name2 = "c:\\prog\\test\\compare2.txt"
-        compare.compare_files(name1, name2)
 #@-others
 #@@language python
 #@@tabwidth -4
