@@ -55,25 +55,24 @@ class ExternalFilesController:
     #@+node:ekr.20150404083533.1: *3* efc.ctor
     def __init__(self, c=None):
         """Ctor for ExternalFiles class."""
-        self.checksum_d = {}
-            # Keys are full paths, values are file checksums.
+        self.checksum_d = {}  # Keys are full paths, values are file checksums.
+        # For efc.on_idle.
+        # Keys are commanders.
+        # Values are cached @bool check-for-changed-external-file settings.
         self.enabled_d = {}
-            # For efc.on_idle.
-            # Keys are commanders.
-            # Values are cached @bool check-for-changed-external-file settings.
+        # List of ExternalFile instances created by self.open_with.
         self.files = []
-            # List of ExternalFile instances created by self.open_with.
+        # Keys are commanders. Values are bools.
+        # Used only to limit traces.
         self.has_changed_d = {}
-            # Keys are commanders. Values are bools.
-            # Used only to limit traces.
+        # Copy of g.app.commanders()
         self.unchecked_commanders = []
-            # Copy of g.app.commanders()
+        # Copy of self file. Only one files is checked at idle time.
         self.unchecked_files = []
-            # Copy of self file. Only one files is checked at idle time.
+        # Keys are full paths, values are modification times.
+        # DO NOT alter directly, use set_time(path) and
+        # get_time(path), see set_time() for notes.
         self._time_d = {}
-            # Keys are full paths, values are modification times.
-            # DO NOT alter directly, use set_time(path) and
-            # get_time(path), see set_time() for notes.
         self.yesno_all_answer = None  # answer, 'yes-all', or 'no-all'
         g.app.idleTimeManager.add_callback(self.on_idle)
     #@+node:ekr.20150405105938.1: *3* efc.entries
@@ -86,7 +85,7 @@ class ExternalFilesController:
         since Leo read it or if the user agrees to overwrite it.
         """
         if c.sqlite_connection and c.mFileName == path:
-            # sqlite database file is never actually overwriten by Leo
+            # sqlite database file is never actually overwritten by Leo
             # so no need to check its timestamp. It is modified through
             # sqlite methods.
             return True
@@ -311,13 +310,13 @@ class ExternalFilesController:
     #@+node:ekr.20150406055221.2: *6* efc.clean_file_name
     def clean_file_name(self, c, ext, p):
         """Compute the file name when subdirectories mirror the node's hierarchy in Leo."""
-        use_extentions = c.config.getBool('open-with-uses-derived-file-extensions')
+        use_extensions = c.config.getBool('open-with-uses-derived-file-extensions')
         ancestors, found = [], False
         for p2 in p.self_and_parents(copy=False):
             h = p2.anyAtFileNodeName()
             if not h:
                 h = p2.h  # Not an @file node: use the entire header
-            elif use_extentions and not found:
+            elif use_extensions and not found:
                 # Found the nearest ancestor @<file> node.
                 found = True
                 base, ext2 = g.os_path_splitext(h)
@@ -427,9 +426,9 @@ class ExternalFilesController:
             elif kind == 'os.spawnv':
                 filename = os.path.basename(arg_tuple[0])
                 vtuple = arg_tuple[1:]
+                # add the name of the program as the first argument.
+                # Change suggested by Jim Sizelove.
                 vtuple.insert(0, filename)
-                    # add the name of the program as the first argument.
-                    # Change suggested by Jim Sizelove.
                 vtuple.append(fn)
                 command = f"os.spawnv({vtuple})"
                 if not testing:
@@ -519,7 +518,7 @@ class ExternalFilesController:
             no_all=is_external_file,
         )
         #
-        # #1961. Re-init the checksum to suppress concurent dialogs.
+        # #1961. Re-init the checksum to suppress concurrent dialogs.
         self.checksum_d[path] = self.checksum(path)
         #
         # #1888: return one of ('yes', 'no', 'yes-all', 'no-all')
