@@ -10,9 +10,24 @@ Leo's core calls this class to allocate all gui objects.
 
 Plugins may define their own gui classes by setting g.app.gui.
 """
+#@+<< imports leoGui.py >>
+#@+node:ekr.20220414080546.1: ** << imports leoGui.py >>
+from typing import Any, Callable, Dict, List, Optional, Tuple, Union
+from typing import TYPE_CHECKING
 from leo.core import leoGlobals as g
 from leo.core import leoFrame
+if TYPE_CHECKING:
+    from leo.core.leoCommands import Commands as Cmdr
+    from leo.core.leoNodes import Position as Pos
+    # from leo.core.leoQt import QtWidgets
+
+else:
+    Cmdr = Pos = Any
     # for NullGui and StringTextWrapper.
+Event = Any
+Widget = Any
+Wrapper = Any
+#@-<< imports leoGui.py >>
 #@+others
 #@+node:ekr.20031218072017.3720: ** class LeoGui
 class LeoGui:
@@ -22,129 +37,174 @@ class LeoGui:
     """
     #@+others
     #@+node:ekr.20031218072017.3722: *3* LeoGui.__init__
-    def __init__(self, guiName):
+    def __init__(self, guiName: str) -> None:
         """Ctor for the LeoGui class."""
-        self.active = None  # Used only by qt_gui.
+        self.active = False  # Used only by qt_gui.
         self.consoleOnly = True  # True if g.es goes to console.
-        self.globalFindTabManager = None
-        self.globalFindTab = None
+        self.globalFindTabManager: Any = None
+        self.globalFindTab: Widget = None
         self.idleTimeClass = None
         self.isNullGui = False
-        self.lastFrame = None
+        self.lastFrame: Wrapper = None
         self.leoIcon = None
         self.mGuiName = guiName
         self.mainLoop = None
-        self.plainTextWidget = None  # For SpellTabHandler class only.
-        self.root = None
-        self.script = None
-        self.splashScreen = None
+        self.plainTextWidget: Widget = None  # For SpellTabHandler class only.
+        self.root: Pos = None
+        self.script: Optional[str] = None
+        self.splashScreen: Widget = None
         self.utils = None
         # To keep pylint happy.
         self.ScriptingControllerClass = NullScriptingControllerClass
         #
         # Define special keys that may be overridden is subclasses.
-        self.ignoreChars = []  # Keys that should always be ignored.
-        self.FKeys = []  # The representation of F-keys.
-        self.specialChars = []  # A list of characters/keys to be handle specially.
+        self.ignoreChars: List[str] = []  # Keys that should always be ignored.
+        self.FKeys: List[str] = []  # The representation of F-keys.
+        self.specialChars: List[str] = []  # A list of characters/keys to be handle specially.
     #@+node:ekr.20061109212618.1: *3* LeoGui: Must be defined only in base class
     #@+node:ekr.20110605121601.18847: *4* LeoGui.create_key_event (LeoGui)
-    def create_key_event(self, c,
-        binding=None, char=None, event=None, w=None,
-        x=None, x_root=None,
-        y=None, y_root=None,
-    ):
+    def create_key_event(
+        self,
+        c: Cmdr,
+        binding: str=None,
+        char: str=None,
+        event: Event=None,
+        w: Wrapper=None,
+        x: int=None,
+        x_root: int=None,
+        y: int=None,
+        y_root: int=None,
+    ) -> Event:
         # Do not call strokeFromSetting here!
         # For example, this would wrongly convert Ctrl-C to Ctrl-c,
         # in effect, converting a user binding from Ctrl-Shift-C to Ctrl-C.
         return LeoKeyEvent(c, char, event, binding, w, x, y, x_root, y_root)
     #@+node:ekr.20031218072017.3740: *4* LeoGui.guiName
-    def guiName(self):
+    def guiName(self) -> str:
         try:
             return self.mGuiName
         except Exception:
             return "invalid gui name"
     #@+node:ekr.20031218072017.2231: *4* LeoGui.setScript
-    def setScript(self, script=None, scriptFileName=None):
+    def setScript(self, script: str=None, scriptFileName: str=None) -> None:
         self.script = script
         self.scriptFileName = scriptFileName
     #@+node:ekr.20110605121601.18845: *4* LeoGui.event_generate (LeoGui)
-    def event_generate(self, c, char, shortcut, w):
+    def event_generate(self, c: Cmdr, char: str, shortcut: str, w: Wrapper) -> None:
         event = self.create_key_event(c, binding=shortcut, char=char, w=w)
         c.k.masterKeyHandler(event)
         c.outerUpdate()
     #@+node:ekr.20061109212618: *3* LeoGu: Must be defined in subclasses
     #@+node:ekr.20031218072017.3725: *4* LeoGui.destroySelf
-    def destroySelf(self):
+    def destroySelf(self) -> None:
         self.oops()
     #@+node:ekr.20031218072017.3730: *4* LeoGui.dialogs
-    def runAboutLeoDialog(self, c, version, theCopyright, url, email):
+    def runAboutLeoDialog(self, c: Cmdr, version: str, theCopyright: str, url: str, email: str) -> Any:
         """Create and run Leo's About Leo dialog."""
         self.oops()
 
-    def runAskLeoIDDialog(self):
+    def runAskLeoIDDialog(self) -> Any:
         """Create and run a dialog to get g.app.LeoID."""
         self.oops()
 
-    def runAskOkDialog(self, c, title, message=None, text="Ok"):
+    def runAskOkDialog(self, c: Cmdr, title: str, message: str=None, text: str="Ok") -> Any:
         """Create and run an askOK dialog ."""
         self.oops()
 
-    def runAskOkCancelNumberDialog(
-        self, c, title, message, cancelButtonText=None, okButtonText=None):
+    def runAskOkCancelNumberDialog(self,
+        c: Cmdr,
+        title: str,
+        message: str,
+        cancelButtonText: str=None,
+        okButtonText: str=None,
+    ) -> Any:
         """Create and run askOkCancelNumber dialog ."""
         self.oops()
 
-    def runAskOkCancelStringDialog(self, c, title, message, cancelButtonText=None,
-                                   okButtonText=None, default="", wide=False):
+    def runAskOkCancelStringDialog(
+        self,
+        c: Cmdr,
+        title: str,
+        message: str,
+        cancelButtonText: str=None,
+        okButtonText: str=None,
+        default: str="",
+        wide: bool=False,
+    ) -> Any:
         """Create and run askOkCancelString dialog ."""
         self.oops()
 
-    def runAskYesNoDialog(self, c, title, message=None, yes_all=False, no_all=False):
+    def runAskYesNoDialog(self,
+        c: Cmdr,
+        title: str,
+        message: str=None,
+        yes_all: bool=False,
+        no_all: bool=False,
+    ) -> Any:
         """Create and run an askYesNo dialog."""
         self.oops()
 
-    def runAskYesNoCancelDialog(self, c, title,
-        message=None, yesMessage="Yes", noMessage="No",
-        yesToAllMessage=None, defaultButton="Yes", cancelMessage=None,
-    ):
+    def runAskYesNoCancelDialog(
+        self,
+        c: Cmdr,
+        title: str,
+        message: str=None,
+        yesMessage: str="Yes",
+        noMessage: str="No",
+        yesToAllMessage: str=None,
+        defaultButton: str="Yes",
+        cancelMessage: str=None,
+    ) -> Any:
         """Create and run an askYesNoCancel dialog ."""
         self.oops()
 
-    def runPropertiesDialog(
-        self, title='Properties', data=None, callback=None, buttons=None):
-        """Dispay a modal TkPropertiesDialog"""
+    def runPropertiesDialog(self,
+        title: str='Properties',
+        data: str=None,
+        callback: Callable=None,
+        buttons: str=None,
+    ) -> Any:
+        """Display a modal TkPropertiesDialog"""
         self.oops()
     #@+node:ekr.20031218072017.3731: *4* LeoGui.file dialogs
-    def runOpenFileDialog(
-        self, c, title, filetypes, defaultextension, multiple=False, startpath=None):
+    def runOpenFileDialog(self,
+        c: Cmdr,
+        title: str,
+        filetypes: List[str],
+        defaultextension: str,
+        multiple: bool=False,
+        startpath: str=None,
+    ) -> Union[List[str], str]:  # Return type depends on the evil multiple keyword.
         """Create and run an open file dialog ."""
         self.oops()
+        return 'no'
 
-    def runSaveFileDialog(self, c, title, filetypes, defaultextension):
+    def runSaveFileDialog(self, c: Cmdr, title: str, filetypes: List[str], defaultextension: str) -> str:
         """Create and run a save file dialog ."""
         self.oops()
+        return 'no'
     #@+node:ekr.20031218072017.3732: *4* LeoGui.panels
-    def createColorPanel(self, c):
+    def createColorPanel(self, c: Cmdr) -> None:
         """Create a color panel"""
         self.oops()
 
-    def createComparePanel(self, c):
+    def createComparePanel(self, c: Cmdr) -> None:
         """Create Compare panel."""
         self.oops()
 
-    def createFindTab(self, c, parentFrame):
+    def createFindTab(self, c: Cmdr, parentFrame: Widget) -> None:
         """Create a find tab in the indicated frame."""
         self.oops()
 
-    def createFontPanel(self, c):
+    def createFontPanel(self, c: Cmdr) -> None:
         """Create a hidden Font panel."""
         self.oops()
 
-    def createLeoFrame(self, c, title):
+    def createLeoFrame(self, c: Cmdr, title: str) -> None:
         """Create a new Leo frame."""
         self.oops()
     #@+node:ekr.20031218072017.3729: *4* LeoGui.runMainLoop
-    def runMainLoop(self):
+    def runMainLoop(self) -> None:
         """Run the gui's main loop."""
         self.oops()
     #@+node:ekr.20031218072017.3733: *4* LeoGui.utils
@@ -155,85 +215,87 @@ class LeoGui:
     # or dialog being created. The commander may be a Commands instance or
     # one of its subcommanders.
     #@+node:ekr.20031218072017.3734: *5* LeoGui.Clipboard
-    def replaceClipboardWith(self, s):
+    def replaceClipboardWith(self, s: str) -> None:
         self.oops()
 
-    def getTextFromClipboard(self):
+    def getTextFromClipboard(self) -> str:
         self.oops()
+        return ''
     #@+node:ekr.20031218072017.3735: *5* LeoGui.Dialog utils
-    def attachLeoIcon(self, window):
+    def attachLeoIcon(self, window: Any) -> None:
         """Attach the Leo icon to a window."""
         self.oops()
 
-    def center_dialog(self, dialog):
+    def center_dialog(self, dialog: str) -> None:
         """Center a dialog."""
         self.oops()
 
-    def create_labeled_frame(
-        self, parent, caption=None, relief="groove", bd=2, padx=0, pady=0):
+    def create_labeled_frame(self,
+        parent: str,
+        caption: str=None,
+        relief: str="groove",
+        bd: int=2,
+        padx: int=0,
+        pady: int=0,
+    ) -> None:
         """Create a labeled frame."""
         self.oops()
 
-    def get_window_info(self, window):
+    def get_window_info(self, window: str) -> Tuple[int, int, int, int]:
         """Return the window information."""
         self.oops()
-    #@+node:ekr.20031218072017.3737: *5* LeoGui.Focus
-    def get_focus(self, *args, **kwargs):
-        """Return the widget that has focus, or the body widget if None."""
-        self.oops()
-
-    def set_focus(self, commander, widget):
-        """Set the focus of the widget in the given commander if it needs to be changed."""
-        self.oops()
+        return 0, 0, 0, 0
     #@+node:ekr.20031218072017.3736: *5* LeoGui.Font
-    def getFontFromParams(self, family, size, slant, weight, defaultSize=12):
+    def getFontFromParams(self, family: str, size: str, slant: str, weight: str, defaultSize: int=12) -> Any:
 
         self.oops()
     #@+node:ekr.20070212145124: *5* LeoGui.getFullVersion
-    def getFullVersion(self, c=None):
+    def getFullVersion(self, c: Cmdr=None) -> str:
         return 'LeoGui: dummy version'
     #@+node:ekr.20070212070820: *5* LeoGui.makeScriptButton
-    def makeScriptButton(self, c,
-        args=None,
-        p=None,
-        script=None,
-        buttonText=None,
-        balloonText='Script Button',
-        shortcut=None,
-        bg='LightSteelBlue1',
-        define_g=True,
-        define_name='__main__',
-        silent=False,
-    ):
+    def makeScriptButton(
+        self,
+        c: Cmdr,
+        args: str=None,
+        p: Pos=None,
+        script: str=None,
+        buttonText: str=None,
+        balloonText: str='Script Button',
+        shortcut: str=None,
+        bg: str='LightSteelBlue1',
+        define_g: bool=True,
+        define_name: str='__main__',
+        silent: bool=False,
+    ) -> None:
         self.oops()
     #@+node:ekr.20070228154059: *3* LeoGui: May be defined in subclasses
     #@+node:ekr.20110613103140.16423: *4* LeoGui.dismiss_spash_screen
-    def dismiss_splash_screen(self):
+    def dismiss_splash_screen(self) -> None:
         pass  # May be overridden in subclasses.
     #@+node:tbrown.20110618095626.22068: *4* LeoGui.ensure_commander_visible
-    def ensure_commander_visible(self, c):
+    def ensure_commander_visible(self, c: Cmdr) -> None:
         """E.g. if commanders are in tabs, make sure c's tab is visible"""
         pass
     #@+node:ekr.20070219084912: *4* LeoGui.finishCreate
-    def finishCreate(self):
+    def finishCreate(self) -> None:
         # This may be overridden in subclasses.
         pass
     #@+node:ekr.20101028131948.5861: *4* LeoGui.killPopupMenu & postPopupMenu
     # These definitions keep pylint happy.
 
-    def postPopupMenu(self, *args, **keys):
+    def postPopupMenu(self, *args: str, **keys: str) -> None:
         pass
     #@+node:ekr.20031218072017.3741: *4* LeoGui.oops
-    def oops(self):
+    def oops(self) -> Any:
         # It is not usually an error to call methods of this class.
         # However, this message is useful when writing gui plugins.
         if 1:
             g.pr("LeoGui oops", g.callers(4), "should be overridden in subclass")
     #@+node:ekr.20170612065049.1: *4* LeoGui.put_help
-    def put_help(self, c, s, short_title):
+    def put_help(self, c: Cmdr, s: str, short_title: str) -> None:
         pass
     #@+node:ekr.20051206103652: *4* LeoGui.widget_name (LeoGui)
-    def widget_name(self, w):
+    def widget_name(self, w: Wrapper) -> str:
         # First try the widget's getName method.
         if not 'w':
             return '<no widget>'
@@ -248,10 +310,20 @@ class LeoKeyEvent:
     """A gui-independent wrapper for gui events."""
     #@+others
     #@+node:ekr.20110605121601.18846: *3* LeoKeyEvent.__init__
-    def __init__(self, c, char, event, binding, w,
-        x=None, y=None, x_root=None, y_root=None
-    ):
+    def __init__(
+        self,
+        c: Cmdr,
+        char: str,
+        event: Event,
+        binding: Any,
+        w: Wrapper,
+        x: int=None,
+        y: int=None,
+        x_root: int=None,
+        y_root: int=None,
+    ) -> None:
         """Ctor for LeoKeyEvent class."""
+        stroke: Any
         if g.isStroke(binding):
             g.trace('***** (LeoKeyEvent) oops: already a stroke', binding, g.callers())
             stroke = binding
@@ -273,22 +345,22 @@ class LeoKeyEvent:
         self.x_root = x_root
         self.y_root = y_root
     #@+node:ekr.20140907103315.18774: *3* LeoKeyEvent.__repr__
-    def __repr__(self):
+    def __repr__(self) -> str:
 
         d = {'c': self.c.shortFileName()}
         for ivar in ('char', 'event', 'stroke', 'w'):
             d[ivar] = getattr(self, ivar)
         return f"LeoKeyEvent:\n{g.objToString(d)}"
     #@+node:ekr.20150511181702.1: *3* LeoKeyEvent.get & __getitem__
-    def get(self, attr):
+    def get(self, attr: str) -> None:
         """Compatibility with g.bunch: return an attr."""
         return getattr(self, attr, None)
 
-    def __getitem__(self, attr):
+    def __getitem__(self, attr: str) -> None:
         """Compatibility with g.bunch: return an attr."""
         return getattr(self, attr, None)
     #@+node:ekr.20140907103315.18775: *3* LeoKeyEvent.type
-    def type(self):
+    def type(self) -> str:
         return 'LeoKeyEvent'
     #@-others
 #@+node:ekr.20031218072017.2223: ** class NullGui (LeoGui)
@@ -296,144 +368,163 @@ class NullGui(LeoGui):
     """Null gui class."""
     #@+others
     #@+node:ekr.20031218072017.2225: *3* NullGui.__init__
-    def __init__(self, guiName='nullGui'):
+    def __init__(self, guiName: str='nullGui') -> None:
         """ctor for the NullGui class."""
         super().__init__(guiName)
         self.clipboardContents = ''
-        self.focusWidget = None
+        self.focusWidget: Widget = None
         self.script = None
-        self.lastFrame = None  # The outer frame, to set g.app.log in runMainLoop.
+        self.lastFrame: Wrapper = None  # The outer frame, to set g.app.log in runMainLoop.
         self.isNullGui = True
-        self.idleTimeClass = g.NullObject
+        self.idleTimeClass: Any = g.NullObject
     #@+node:ekr.20031218072017.3744: *3* NullGui.dialogs
-    def runAboutLeoDialog(self, c, version, theCopyright, url, email):
+    def runAboutLeoDialog(self, c: Cmdr, version: str, theCopyright: str, url: str, email: str) -> str:
         return self.simulateDialog("aboutLeoDialog", None)
 
-    def runAskLeoIDDialog(self):
+    def runAskLeoIDDialog(self) -> str:
         return self.simulateDialog("leoIDDialog", None)
 
-    def runAskOkDialog(self, c, title, message=None, text="Ok"):
+    def runAskOkDialog(self, c: Cmdr, title: str, message: str=None, text: str="Ok") -> str:
         return self.simulateDialog("okDialog", "Ok")
 
-    def runAskOkCancelNumberDialog(self, c, title, message,
-        cancelButtonText=None,
-        okButtonText=None,
-    ):
-        return self.simulateDialog("numberDialog", -1)
+    def runAskOkCancelNumberDialog(
+        self,
+        c: Cmdr,
+        title: str,
+        message: str,
+        cancelButtonText: str=None,
+        okButtonText: str=None,
+    ) -> str:
+        return self.simulateDialog("numberDialog", 'no')
 
-    def runAskOkCancelStringDialog(self, c, title, message,
-        cancelButtonText=None,
-        okButtonText=None,
-        default="",
-        wide=False,
-    ):
+    def runAskOkCancelStringDialog(
+        self,
+        c: Cmdr,
+        title: str,
+        message: str,
+        cancelButtonText: str=None,
+        okButtonText: str=None,
+        default: str="",
+        wide: bool=False,
+    ) -> str:
         return self.simulateDialog("stringDialog", '')
 
-    def runCompareDialog(self, c):
+    def runCompareDialog(self, c: Cmdr) -> str:
         return self.simulateDialog("compareDialog", '')
 
-    def runOpenFileDialog(self, c, title, filetypes, defaultextension,
-        multiple=False,
-        startpath=None,
-    ):
+    def runOpenFileDialog(
+        self,
+        c: Cmdr,
+        title: str,
+        filetypes: List[str],
+        defaultextension: str,
+        multiple: bool=False,
+        startpath: str=None,
+    ) -> Union[List[str], str]:  # Return type depends on the evil multiple keyword.
         return self.simulateDialog("openFileDialog", None)
 
-    def runSaveFileDialog(self, c, title, filetypes, defaultextension):
+    def runSaveFileDialog(self, c: Cmdr, title: str, filetypes: List[str], defaultextension: str) -> str:
         return self.simulateDialog("saveFileDialog", None)
 
-    def runAskYesNoDialog(self, c, title,
-        message=None,
-        yes_all=False,
-        no_all=False,
-    ):
+    def runAskYesNoDialog(
+        self,
+        c: Cmdr,
+        title: str,
+        message: str=None,
+        yes_all: bool=False,
+        no_all: bool=False,
+    ) -> str:
         return self.simulateDialog("yesNoDialog", "no")
 
-    def runAskYesNoCancelDialog(self, c, title,
-        message=None,
-        yesMessage="Yes",
-        noMessage="No",
-        yesToAllMessage=None,
-        defaultButton="Yes",
-        cancelMessage=None,
-    ):
+    def runAskYesNoCancelDialog(
+        self,
+        c: Cmdr,
+        title: str,
+        message: str=None,
+        yesMessage: str="Yes",
+        noMessage: str="No",
+        yesToAllMessage: str=None,
+        defaultButton: str="Yes",
+        cancelMessage: str=None,
+    ) -> str:
         return self.simulateDialog("yesNoCancelDialog", "cancel")
 
-    def simulateDialog(self, key, defaultVal):
+    def simulateDialog(self, key: str, defaultVal: str) -> str:
         return defaultVal
     #@+node:ekr.20170613101737.1: *3* NullGui.clipboard & focus
-    def get_focus(self, *args, **kwargs):
+    def get_focus(self, *args: str, **kwargs: str) -> Widget:
         return self.focusWidget
 
-    def getTextFromClipboard(self):
+    def getTextFromClipboard(self) -> str:
         return self.clipboardContents
 
-    def replaceClipboardWith(self, s):
+    def replaceClipboardWith(self, s: str) -> None:
         self.clipboardContents = s
 
-    def set_focus(self, commander, widget):
+    def set_focus(self, commander: str, widget: str) -> None:
         self.focusWidget = widget
     #@+node:ekr.20070301171901: *3* NullGui.do nothings
-    def alert(self, c, message):
+    def alert(self, c: Cmdr, message: str) -> None:
         pass
 
-    def attachLeoIcon(self, window):
+    def attachLeoIcon(self, window: Any) -> None:
         pass
 
-    def destroySelf(self):
+    def destroySelf(self) -> None:
         pass
 
-    def finishCreate(self):
+    def finishCreate(self) -> None:
         pass
 
-    def getFontFromParams(self, family, size, slant, weight, defaultSize=12):
-        return g.app.config.defaultFont
-
-    def getIconImage(self, name):
+    def getFontFromParams(self, family: str, size: str, slant: str, weight: str, defaultSize: int=12) -> Any:
         return None
 
-    def getImageImage(self, name):
+    def getIconImage(self, name: str) -> None:
         return None
 
-    def getTreeImage(self, c, path):
+    def getImageImage(self, name: str) -> None:
         return None
 
-    def get_window_info(self, window):
+    def getTreeImage(self, c: Cmdr, path: str) -> None:
+        return None
+
+    def get_window_info(self, window: str) -> Tuple[int, int, int, int]:
         return 600, 500, 20, 20
 
-    def onActivateEvent(self, *args, **keys):
+    def onActivateEvent(self, *args: str, **keys: str) -> None:
         pass
 
-    def onDeactivateEvent(self, *args, **keys):
+    def onDeactivateEvent(self, *args: str, **keys: str) -> None:
         pass
 
-    def set_top_geometry(self, w, h, x, y):
+    def set_top_geometry(self, w: Wrapper, h: str, x: str, y: str) -> None:
         pass
     #@+node:ekr.20070228155807: *3* NullGui.isTextWidget & isTextWrapper
-    def isTextWidget(self, w):
+    def isTextWidget(self, w: Wrapper) -> bool:
         return True  # Must be True for unit tests.
 
-    def isTextWrapper(self, w):
+    def isTextWrapper(self, w: Wrapper) -> bool:
         """Return True if w is a Text widget suitable for text-oriented commands."""
         return w and getattr(w, 'supportsHighLevelInterface', None)
     #@+node:ekr.20031218072017.2230: *3* NullGui.oops
-    def oops(self):
+    def oops(self) -> None:
         g.trace("NullGui", g.callers(4))
     #@+node:ekr.20070301172456: *3* NullGui.panels
-    def createComparePanel(self, c):
+    def createComparePanel(self, c: Cmdr) -> None:
         """Create Compare panel."""
         self.oops()
 
-    def createFindTab(self, c, parentFrame):
+    def createFindTab(self, c: Cmdr, parentFrame: Widget) -> None:
         """Create a find tab in the indicated frame."""
         pass  # Now always done during startup.
 
-    def createLeoFrame(self, c, title):
+    def createLeoFrame(self, c: Cmdr, title: str) -> Widget:
         """Create a null Leo Frame."""
         gui = self
         self.lastFrame = leoFrame.NullFrame(c, title, gui)
         return self.lastFrame
     #@+node:ekr.20031218072017.2229: *3* NullGui.runMainLoop
-    def runMainLoop(self):
+    def runMainLoop(self) -> None:
         """Run the null gui's main loop."""
         if self.script:
             frame = self.lastFrame
@@ -449,42 +540,42 @@ class NullScriptingControllerClass:
 
     This keeps pylint happy."""
 
-    def __init__(self, c, iconBar=None):
+    def __init__(self, c: Cmdr, iconBar: Widget=None) -> None:
         self.c = c
         self.iconBar = iconBar
 
-    def createAllButtons(self):
+    def createAllButtons(self) -> None:
         pass
 #@+node:ekr.20171128093401.1: ** class StringCheckBox (leoGui.py)
 class StringCheckBox:
     """Simulate a QCheckBox."""
 
-    def __init__(self, name, label=None):
+    def __init__(self, name: str, label: str=None) -> None:
         self.label = label
         self.name = name
         self.value = True
 
-    def checkState(self):
+    def checkState(self) -> bool:
         return self.value
 
     isChecked = checkState
 
-    def objectName(self):
+    def objectName(self) -> str:
         return self.name
 
-    def setCheckState(self, value):
+    def setCheckState(self, value: bool) -> None:
         self.value = value
 
-    def toggle(self):
+    def toggle(self) -> None:
         self.value = not self.value
-#@+node:ekr.20210221130549.1: ** class StringFindTabManager (leoGui.py) (new)
+#@+node:ekr.20210221130549.1: ** class StringFindTabManager (leoGui.py)
 class StringFindTabManager:
     """A string-based FindTabManager class for unit tests."""
     #@+others
     #@+node:ekr.20210221130549.2: *3*  sftm.ctor
     #@@nobeautify
 
-    def __init__(self, c):
+    def __init__(self, c: Cmdr) -> None:
         """Ctor for the FindTabManager class."""
         self.c = c
         self.entry_focus = None  # Accessed directly from code(!)
@@ -501,23 +592,24 @@ class StringFindTabManager:
         self.check_box_whole_word       = StringCheckBox('whole_word')
         # Radio buttons...
         self.radio_button_entire_outline  = StringRadioButton('entire_outline')
+        self.radio_button_file_only       = StringRadioButton('file_only')
         self.radio_button_node_only       = StringRadioButton('node_only')
         self.radio_button_suboutline_only = StringRadioButton('suboutline_only')
         # Init the default values.
         self.init_widgets()
     #@+node:ekr.20210221130549.5: *3* sftm.clear_focus & init_focus & set_entry_focus
-    def clear_focus(self):
+    def clear_focus(self) -> None:
         pass
 
-    def init_focus(self):
+    def init_focus(self) -> None:
         pass
 
-    def set_entry_focus(self):
+    def set_entry_focus(self) -> None:
         pass
     #@+node:ekr.20210221130549.4: *3* sftm.get_settings
     #@@nobeautify
 
-    def get_settings(self):
+    def get_settings(self) -> Any:
         """
         Return a g.bunch representing all widget values.
 
@@ -528,6 +620,7 @@ class StringFindTabManager:
             find_text   = self.find_findbox.text(),
             change_text = self.find_replacebox.text(),
             # Find options...
+            file_only       = self.radio_button_file_only.isChecked(),
             ignore_case     = self.check_box_ignore_case.isChecked(),
             mark_changes    = self.check_box_mark_changes.isChecked(),
             mark_finds      = self.check_box_mark_finds.isChecked(),
@@ -539,7 +632,7 @@ class StringFindTabManager:
             whole_word      = self.check_box_whole_word.isChecked(),
         )
     #@+node:ekr.20210221130549.7: *3* sftm.init_widgets
-    def init_widgets(self):
+    def init_widgets(self) -> None:
         """
         Init widgets and ivars from c.config settings.
         Create callbacks that always keep the LeoFind ivars up to date.
@@ -572,6 +665,7 @@ class StringFindTabManager:
                 w.toggle()
         # Radio buttons
         table3 = (
+            ('file_only', 'file_only', 'radio_button_file_only'),  # #2684.
             ('node_only', 'node_only', 'radio_button_node_only'),
             ('entire_outline', None, 'radio_button_entire_outline'),
             ('suboutline_only', 'suboutline_only', 'radio_button_suboutline_only'),
@@ -590,7 +684,7 @@ class StringFindTabManager:
             if val != w.isChecked():
                 w.toggle()
     #@+node:ekr.20210312122351.1: *3* sftm.set_body_and_headline_checkbox
-    def set_body_and_headline_checkbox(self):
+    def set_body_and_headline_checkbox(self) -> None:
         """Return the search-body and search-headline checkboxes to their defaults."""
         # #1840: headline-only one-shot
         c = self.c
@@ -608,9 +702,10 @@ class StringFindTabManager:
     #@+node:ekr.20210221130549.8: *3* sftm.set_radio_button
     #@@nobeautify
 
-    def set_radio_button(self, name):
+    def set_radio_button(self, name: str) -> None:
         """Set the value of the radio buttons"""
         d = {
+            'file-only':       self.radio_button_file_only,
             'node-only':       self.radio_button_node_only,
             'entire-outline':  self.radio_button_entire_outline,
             'suboutline-only': self.radio_button_suboutline_only,
@@ -619,31 +714,31 @@ class StringFindTabManager:
         if not w.isChecked():
             w.toggle()
     #@+node:ekr.20210221130549.3: *3* sftm.text getters/setters
-    def get_find_text(self):
+    def get_find_text(self) -> str:
         s = self.find_findbox.text()
         if s and s[-1] in ('\r', '\n'):
             s = s[:-1]
         return s
 
-    def get_change_text(self):
+    def get_change_text(self) -> str:
         s = self.find_replacebox.text()
         if s and s[-1] in ('\r', '\n'):
             s = s[:-1]
         return s
 
-    def set_find_text(self, s):
+    def set_find_text(self, s: str) -> None:
         w = self.find_findbox
         w.clear()
         w.insert(s)
 
-    def set_change_text(self, s):
+    def set_change_text(self, s: str) -> None:
         w = self.find_replacebox
         w.clear()
         w.insert(s)
     #@+node:ekr.20210221130549.9: *3* sftm.toggle_checkbox
     #@@nobeautify
 
-    def toggle_checkbox(self, checkbox_name):
+    def toggle_checkbox(self, checkbox_name: str) -> None:
         """Toggle the value of the checkbox whose name is given."""
         d = {
             'ignore_case':     self.check_box_ignore_case,
@@ -665,54 +760,54 @@ class StringGui(LeoGui):
     """
     #@+others
     #@+node:ekr.20170613095422.7: *3* StringGui.oops
-    def oops(self):
+    def oops(self) -> None:
 
         g.trace("StringGui", g.callers(4))
     #@+node:ekr.20170613114120.1: *3* StringGui.runMainLoop
-    def runMainLoop(self):
+    def runMainLoop(self) -> None:
         self.oops()
     #@-others
 #@+node:ekr.20171128093503.1: ** class StringLineEdit (leoGui)
 class StringLineEdit:
     """Simulate a QLineEdit."""
 
-    def __init__(self, name, disabled=False):
+    def __init__(self, name: str, disabled: bool=False) -> None:
         self.disabled = disabled
         self.name = name
         self.pos = 0
         self.s = ''
 
-    def clear(self):
+    def clear(self) -> None:
         self.pos = 0
         self.s = ''
 
-    def insert(self, s):
+    def insert(self, s: str) -> None:
         if s:
             i = self.pos
             self.s = self.s[:i] + s + self.s[i:]
             self.pos += len(s)
 
-    def objectName(self):
+    def objectName(self) -> str:
         return self.name
 
-    def text(self):
+    def text(self) -> str:
         return self.s
 #@+node:ekr.20171128093602.1: ** class StringRadioButton (leoGui.py)
 class StringRadioButton:
     """Simulate a QRadioButton."""
 
-    def __init__(self, name, label=None):
+    def __init__(self, name: str, label: str=None) -> None:
         self.label = label
         self.name = name
         self.value = True
 
-    def isChecked(self):
+    def isChecked(self) -> bool:
         return self.value
 
-    def objectName(self):
+    def objectName(self) -> str:
         return self.name
 
-    def toggle(self):
+    def toggle(self) -> None:
         self.value = not self.value
 #@+node:ekr.20031218072017.3742: ** class UnitTestGui (NullGui)
 class UnitTestGui(NullGui):
@@ -720,22 +815,22 @@ class UnitTestGui(NullGui):
     # Presently used only by the import/export unit tests.
     #@+others
     #@+node:ekr.20031218072017.3743: *3* UnitTestGui.__init__
-    def __init__(self, theDict=None):
+    def __init__(self, theDict: Dict=None) -> None:
         """ctor for the UnitTestGui class."""
         self.oldGui = g.app.gui
         super().__init__("UnitTestGui")
         self.theDict = {} if theDict is None else theDict
         g.app.gui = self
 
-    def destroySelf(self):
+    def destroySelf(self) -> None:
         g.app.gui = self.oldGui
     #@+node:ekr.20071128094234.1: *3* UnitTestGui.createSpellTab
-    def createSpellTab(self, c, spellHandler, tabName):
+    def createSpellTab(self, c: Cmdr, spellHandler: str, tabName: str) -> None:
         pass  # This method keeps pylint happy.
     #@+node:ekr.20111001155050.15484: *3* UnitTestGui.runAtIdle
     if 1:  # Huh?
 
-        def runAtIdle(self, aFunc):
+        def runAtIdle(self, aFunc: Callable) -> None:
             """Run aFunc immediately for a unit test.
 
             This is a kludge, but it is probably the best that can be done.
