@@ -39,9 +39,11 @@ leoVersion.version:     Leo's version number.
 # 6.5:    October 22, 2021.
 # 6.6:    March 31, 2022.
 # 6.6.1:  April 28, 2022.
+# 6.6.2:  May 25, 2022.
+# 6.6.3:  July 22, 2022.
 #@-<< version dates >>
-version = '6.6.1'
-static_date = 'April 28, 2022'
+version = '6.6.3'
+static_date = 'July 22, 2022'
 #@@language python
 #@@tabwidth -4
 #@-leo
