@@ -1,8 +1,8 @@
 #@+leo-ver=5-thin
-#@+node:tbrown.20091029123555.5319: * @file attrib_edit.py
+#@+node:tbrown.20091029123555.5319: * @file ../plugins/attrib_edit.py
 #@+<< docstring >>
 #@+node:tbrown.20091009210724.10972: ** << docstring >>
-r''' Edits user attributes in a Qt frame.
+r""" Edits user attributes in a Qt frame.
 
 This plugin creates a frame for editing attributes similar to::
 
@@ -99,34 +99,37 @@ plugins. Here are some points of interest:
   attribute list each plugin could address this, with unordered
   presentation in the absence of the client plugin.
 
-'''
+"""
 #@-<< docstring >>
 # Written by TNB.
-
-import leo.core.leoGlobals as g
-if g.app.gui.guiName() == "qt":
-    from leo.core.leoQt import QtCore,QtWidgets
+from typing import Any, List, Tuple
+from leo.core import leoGlobals as g
+from leo.core.leoQt import isQt6, QtConst, QtCore, QtWidgets
+from leo.core.leoQt import DialogCode, Orientation
+#
+# Fail fast, right after all imports.
+g.assertUi('qt')  # May raise g.UiTypeException, caught by the plugins manager.
 
 #@+others
 #@+node:tbrown.20091009210724.10975: ** init
 def init():
-    '''Return True if the plugin has loaded successfully.'''
+    """Return True if the plugin has loaded successfully."""
     if g.app.gui.guiName() != "qt":
         print('attrib_edit.py plugin not loading because gui is not Qt')
         return False
-    g.registerHandler('after-create-leo-frame',onCreate)
+    g.registerHandler('after-create-leo-frame', onCreate)
     g.plugin_signon(__name__)
     return True
 #@+node:tbrown.20091009210724.10976: ** onCreate
-def onCreate (tag,key):
+def onCreate(tag, key):
 
     c = key.get('c')
 
     attrib_edit_Controller(c)
 #@+node:tbrown.20091103080354.1400: ** class AttributeGetter
-class AttributeGetter(object):
+class AttributeGetter:
 
-    implementations = []
+    implementations: List[Any] = []
 
     typeMap = {
         '_int': int,
@@ -166,12 +169,7 @@ class AttributeGetter(object):
         raise NotImplementedError
 #@+node:tbrown.20091103080354.1402: ** class AttributeGetterUA
 class AttributeGetterUA(AttributeGetter):
-
     #@+others
-    #@+node:tbrown.20091103080354.6240: *3* __init__
-    def __init__(self, c):
-
-        AttributeGetter.__init__(self, c)
     #@+node:tbrown.20091103080354.1409: *3* recSearch
     def recSearch(self, d, path, ans):
         """recursive search of tree of dicts for values whose
@@ -183,7 +181,7 @@ class AttributeGetterUA(AttributeGetter):
         for k in d:
             if isinstance(d[k], dict):
                 if k not in ('_edit', '_view'):
-                    self.recSearch(d[k], path+[k], ans)
+                    self.recSearch(d[k], path + [k], ans)
                 else:
                     # k == '_edit' or '_view'
                     for ek in d[k]:
@@ -192,11 +190,11 @@ class AttributeGetterUA(AttributeGetter):
                             type_ = self.typeMap[ek]
                             for ekt in d[k][ek]:
                                 ans.append((self,
-                                    ekt, d[k][ek][ekt], tuple(path+['_edit',ek,ekt]),
+                                    ekt, d[k][ek][ekt], tuple(path + ['_edit', ek, ekt]),
                                     type_, k != '_edit'))
                         else:
                             ans.append((self,
-                                ek, d[k][ek], tuple(path+['_edit',ek]), str, k != '_edit'))
+                                ek, d[k][ek], tuple(path + ['_edit', ek]), str, k != '_edit'))
     #@+node:tbrown.20091103080354.1410: *3* getAttribs
     def getAttribs(self, v):
         """Return a list of tuples describing editable uAs.
@@ -214,7 +212,7 @@ class AttributeGetterUA(AttributeGetter):
         v.uA['inventory']['_edit']['_int']['cars'] respectively
         """
 
-        ans = []
+        ans: List[Tuple] = []
         d = v.u
 
         self.recSearch(d, [], ans)
@@ -253,11 +251,11 @@ class AttributeGetterUA(AttributeGetter):
     #@+node:tbrown.20091103080354.1432: *3* createAttrib
     def createAttrib(self, v, gui_parent=None):
 
-        path,ok = QtWidgets.QInputDialog.getText(gui_parent,
+        path, ok = QtWidgets.QInputDialog.getText(gui_parent,
             "Enter attribute path",
             "Enter path to attribute (space separated words)")
 
-        ns = str(path).split()  # not the QString
+        ns = str(path).split()
         if not ok or not ns:
             g.es("Cancelled")
             return
@@ -266,7 +264,7 @@ class AttributeGetterUA(AttributeGetter):
         type_ = '_edit'
 
         if '|' in ns[-1]:
-            nslist = [ ns[:-1] + [i.strip()] for i in ns[-1].split('|') ]
+            nslist = [ns[:-1] + [i.strip()] for i in ns[-1].split('|')]
         else:
             nslist = [ns]
 
@@ -281,18 +279,13 @@ class AttributeGetterUA(AttributeGetter):
     #@+node:tbrown.20091103080354.1433: *3* longDescrip
     def longDescrip(self, path):
 
-        return '.'.join([j for j in path if j not in ('_edit','_view')])
+        return '.'.join([j for j in path if j not in ('_edit', '_view')])
     #@-others
 
 AttributeGetter.register(AttributeGetterUA)
 #@+node:tbrown.20091103080354.1420: ** class AttributeGetterAt
 class AttributeGetterAt(AttributeGetter):
-
     #@+others
-    #@+node:tbrown.20091103080354.6238: *3* __init__
-    def __init__(self, c):
-
-        AttributeGetter.__init__(self, c)
     #@+node:tbrown.20091103080354.1422: *3* getAttribs
     def getAttribs(self, v):
         """Return a list of tuples describing editable uAs.
@@ -319,7 +312,7 @@ class AttributeGetterAt(AttributeGetter):
                     continue
                 if len(words) == 1:
                     words.append('')
-                ans.append( (self, words[0], words[1], words[0], str, False) )
+                ans.append((self, words[0], words[1], words[0], str, False))
         return ans
     #@+node:tbrown.20091103080354.6237: *3* setAttrib
     def setAttrib(self, v, path, value):
@@ -364,17 +357,12 @@ class AttributeGetterAt(AttributeGetter):
 AttributeGetter.register(AttributeGetterAt)
 #@+node:tbrown.20091103080354.1427: ** class AttributeGetterColon
 class AttributeGetterColon(AttributeGetter):
-
     #@+others
-    #@+node:tbrown.20091103080354.6242: *3* __init__
-    def __init__(self, c):
-
-        AttributeGetter.__init__(self, c)
     #@+node:tbrown.20091103080354.1428: *3* getAttribs
     def getAttribs(self, v):
 
         ans = []
-        parts = v.b.split('\n',100)
+        parts = v.b.split('\n', 100)
 
         for i in parts[:99]:
             if not i or i[0].isspace():
@@ -383,15 +371,15 @@ class AttributeGetterColon(AttributeGetter):
             if words and words[0] and words[0][-1] == ':':
                 if len(words) == 1:
                     words.append('')
-                ans.append( (self, words[0][:-1], words[1], words[0][:-1], str, False) )
+                ans.append((self, words[0][:-1], words[1], words[0][:-1], str, False))
 
         return ans
     #@+node:tbrown.20091103080354.6246: *3* setAttrib
     def setAttrib(self, v, path, value):
 
-        parts = v.b.split('\n',100)
+        parts = v.b.split('\n', 100)
 
-        for n,i in enumerate(parts[:99]):
+        for n, i in enumerate(parts[:99]):
             words = i.split(None, 1)
             if words and words[0] and words[0][-1] == ':' and words[0][:-1] == path:
                 parts[n] = "%s: %s" % (path, value)
@@ -402,9 +390,9 @@ class AttributeGetterColon(AttributeGetter):
     #@+node:tbrown.20091103080354.6248: *3* delAttrib
     def delAttrib(self, v, path):
 
-        parts = v.b.split('\n',100)
+        parts = v.b.split('\n', 100)
 
-        for n,i in enumerate(parts[:99]):
+        for n, i in enumerate(parts[:99]):
             words = i.split(None, 1)
             if words and words[0] and words[0][-1] == ':' and words[0][:-1] == path:
                 del parts[n]
@@ -424,14 +412,14 @@ class AttributeGetterColon(AttributeGetter):
 
 AttributeGetter.register(AttributeGetterColon)
 #@+node:tbrown.20091028131637.1353: ** class ListDialog
-class ListDialog(QtWidgets.QDialog):
+class ListDialog(QtWidgets.QDialog):  # type:ignore
 
     #@+others
-    #@+node:tbrown.20091028131637.1354: *3* __init__
+    #@+node:tbrown.20091028131637.1354: *3* __init__ (attrib_edit.py)
     def __init__(self, parent, title, text, entries):
 
         self.entries = entries
-        QtWidgets.QDialog.__init__(self, parent)
+        super().__init__(parent)
         vbox = QtWidgets.QVBoxLayout()
         sa = QtWidgets.QScrollArea()
         salo = QtWidgets.QVBoxLayout()
@@ -443,7 +431,7 @@ class ListDialog(QtWidgets.QDialog):
             cb = QtWidgets.QCheckBox(entry[0])
             self.buttons.append(cb)
             if entry[1]:
-                cb.setCheckState(QtCore.Qt.Checked)
+                cb.setChecked(True if isQt6 else QtConst.Checked)
             hbox.addWidget(cb)
             salo.addLayout(hbox)
         sa.setWidget(frame)
@@ -452,9 +440,9 @@ class ListDialog(QtWidgets.QDialog):
         ok = QtWidgets.QPushButton("Ok")
         cancel = QtWidgets.QPushButton("Cancel")
         ok.clicked.connect(self.writeBack)
+        # QtCore.QObject.connect(ok, QtCore.SIGNAL('clicked(bool)'), self.writeBack)
+        # QtCore.QObject.connect(cancel, QtCore.SIGNAL('clicked(bool)'), self.reject)
         cancel.clicked.connect(self.reject)
-            # QtCore.QObject.connect(ok, QtCore.SIGNAL('clicked(bool)'), self.writeBack)
-            # QtCore.QObject.connect(cancel, QtCore.SIGNAL('clicked(bool)'), self.reject)
         hbox.addWidget(ok)
         hbox.addWidget(cancel)
         vbox.addLayout(hbox)
@@ -462,12 +450,12 @@ class ListDialog(QtWidgets.QDialog):
     #@+node:tbrown.20091028131637.1359: *3* writeBack
     def writeBack(self, event=None):
 
-        for n,i in enumerate(self.buttons):
+        for n, i in enumerate(self.buttons):
             self.entries[n][1] = (i.isChecked())
         self.accept()
     #@-others
 #@+node:tbrown.20091010211613.5257: ** class editWatcher
-class editWatcher(object):
+class editWatcher:
     """class to supply widget for editing attribute and handle
     its textChanged signal"""
 
@@ -492,8 +480,6 @@ class editWatcher(object):
         if not self._widget:
             self._widget = w = QtWidgets.QLineEdit(str(self.value))
             w.textChanged.connect(self.updateValue)
-                # QtCore.QObject.connect(w,
-                    # QtCore.SIGNAL("textChanged(QString)"), self.updateValue)
             self._widget.focusOutEvent = self.lostFocus
             # see lostFocus()
         return self._widget
@@ -522,13 +508,13 @@ class editWatcher(object):
     #X         a = a.setdefault(i, {})
     #X     a[path[-1]] = value
 #@+node:tbrown.20091009210724.10979: ** class attrib_edit_Controller
-class attrib_edit_Controller(object):
+class attrib_edit_Controller:
 
-    '''A per-commander class that manages attribute editing.'''
+    """A per-commander class that manages attribute editing."""
 
     #@+others
     #@+node:tbrown.20091009210724.10981: *3* __init__ & reloadSettings (attrib_edit_Controller)
-    def __init__ (self, c):
+    def __init__(self, c):
 
         self.c = c
         c.attribEditor = self
@@ -545,7 +531,7 @@ class attrib_edit_Controller(object):
         self.guiMode = 'tab'
         # body mode in not compatible with nested_splitter, causes hard crash
         if self.guiMode == 'body':
-            self.holder = QtWidgets.QSplitter(QtCore.Qt.Vertical)
+            self.holder = QtWidgets.QSplitter(Orientation.Vertical)
             self.holder.setMinimumWidth(300)
             parent = c.frame.top.leo_body_frame.parent()
             self.holder.addWidget(c.frame.top.leo_body_frame)
@@ -555,8 +541,8 @@ class attrib_edit_Controller(object):
             self.parent = QtWidgets.QFrame()
             self.holder = QtWidgets.QHBoxLayout()
             self.parent.setLayout(self.holder)
-            c.frame.log.createTab('Attribs', widget = self.parent)
-            
+            c.frame.log.createTab('Attribs', widget=self.parent)
+
     def reloadSettings(self):
         c = self.c
         c.registerReloadSettings(self)
@@ -564,7 +550,7 @@ class attrib_edit_Controller(object):
         self.getsetters = []
         for i in AttributeGetter.implementations:
             s = i(c)
-            self.getsetters.append([s, (s.name() in active) ])
+            self.getsetters.append([s, (s.name() in active)])
         if not active:
             self.getsetters[0][1] = True  # turn on the first one
     #@+node:tbrown.20091009210724.10983: *3* __del__
@@ -591,10 +577,11 @@ class attrib_edit_Controller(object):
         pnl.setAutoFillBackground(True)
         w.addWidget(pnl)
     #@+node:tbrown.20091009210724.11047: *3* updateEditor
-    def updateEditor(self,tag,k):
+    def updateEditor(self, tag, k):
         """update edit panel when new node selected"""
 
-        if k['c'] != self.c: return  # not our problem
+        if k['c'] != self.c:
+            return  # not our problem
 
         self.updateEditorInt()
     #@+node:tbrown.20091028100922.1493: *3* updateEditorInt
@@ -637,7 +624,7 @@ class attrib_edit_Controller(object):
                         # else:
                             # ans.append((ek, d[k][ek], tuple(path+['_edit',ek]), str, k != '_edit'))
     #@+node:tbrown.20091103080354.1406: *3* getAttribs
-    def getAttribs(self, v = None):
+    def getAttribs(self, v=None):
         """Return a list of tuples describing editable uAs.
 
         (class, name, value, path, type, readonly)
@@ -666,7 +653,7 @@ class attrib_edit_Controller(object):
 
 
         for ns in ans:
-            self.attrPaths.add( (ns[0], ns[1], ns[3]) )  # class, name, path
+            self.attrPaths.add((ns[0], ns[1], ns[3]))  # class, name, path
 
         return ans
     #@+node:tbrown.20091029101116.1413: *3* addAttrib
@@ -708,38 +695,28 @@ class attrib_edit_Controller(object):
     #@+node:tbrown.20091028131637.1358: *3* manageAttrib
     def manageAttrib(self):
 
-        attribs = [(i[0],i[1],i[3]) for i in self.getAttribs()]
-
+        attribs = [(i[0], i[1], i[3]) for i in self.getAttribs()]
         dat = []
         for attr in self.attrPaths:
-
             txt = attr[0].longDescrip(attr[2])
-
             active = attr in attribs
-
             dat.append([txt, active, attr])
-
         if not dat:
             g.es('No attributes seen (yet)')
             return
-
         dat.sort(key=lambda x: x[0])
-
         res = ListDialog(self.parent, "Enter attribute path",
-            "Enter path to attribute (space separated words)",
-            dat)
-
+            "Enter path to attribute (space separated words)", dat)
         res.exec_()
-
-        if res.result() == QtWidgets.QDialog.Rejected:
+        if res.result() == DialogCode.Rejected:
             return
 
         # check for deletions
         for i in dat:
             if i[2] in attribs and not i[1]:
                 res = QtWidgets.QMessageBox(QtWidgets.QMessageBox.Question,
-                    "Really delete attributes?","Really delete attributes?",
-                    QtWidgets.QMessageBox.Ok|QtWidgets.QMessageBox.Cancel, self.parent)
+                    "Really delete attributes?", "Really delete attributes?",
+                    QtWidgets.QMessageBox.Ok | QtWidgets.QMessageBox.Cancel, self.parent)
                 if res.exec_() == QtWidgets.QMessageBox.Cancel:
                     return
                 break
@@ -757,18 +734,17 @@ class attrib_edit_Controller(object):
     #@+node:tbrown.20091103080354.1415: *3* manageModes
     def manageModes(self):
 
-        modes = [ [i[0].name(), i[1]] for i in self.getsetters ]
+        modes = [[i[0].name(), i[1]] for i in self.getsetters]
 
         res = ListDialog(self.parent, "Enter attribute path",
             "Enter path to attribute (space separated words)",
             modes)
 
         res.exec_()
-
-        if res.result() == QtWidgets.QDialog.Rejected:
+        if res.result() == DialogCode.Rejected:
             return
 
-        for n,i in enumerate(modes):
+        for n, i in enumerate(modes):
             self.getsetters[n][1] = i[1]
 
         self.updateEditorInt()
