@@ -1,19 +1,16 @@
 #@+leo-ver=5-thin
-#@+node:ekr.20140723122936.18138: * @file importers/html.py
-'''The @auto importer for HTML.'''
-import leo.plugins.importers.xml as xml
+#@+node:ekr.20140723122936.18138: * @file ../plugins/importers/html.py
+"""The @auto importer for HTML."""
+from leo.plugins.importers import xml
 Xml_Importer = xml.Xml_Importer
 #@+others
 #@+node:ekr.20140723122936.18136: ** class Html_Importer(Xml_Importer)
 class Html_Importer(Xml_Importer):
 
     def __init__(self, importCommands, **kwargs):
-        '''Html_Importer.__init__'''
-        # Init the base class.
-        Xml_Importer.__init__(self,
-            importCommands,
-            tags_setting='import_html_tags',
-        )
+        """Html_Importer.__init__"""
+        super().__init__(importCommands,
+            tags_setting='import_html_tags')
         self.name = 'html'
         self.void_tags = [
             # A small kludge: add !DOCTYPE.
@@ -25,7 +22,7 @@ class Html_Importer(Xml_Importer):
         ]
 #@-others
 importer_dict = {
-    'class': Html_Importer,
+    'func': Html_Importer.do_import(),
     'extensions': ['.html', '.htm',],
 }
 #@@language python
