@@ -75,6 +75,7 @@ If True, when expanding as above, skip blank dict entries.
 import io
 import xml.sax
 import xml.sax.saxutils
+from typing import List
 from leo.core import leoGlobals as g
 from leo.core import leoNodes
 from leo.core import leoPlugins
@@ -82,8 +83,8 @@ from leo.core import leoPlugins
 StringIO = io.StringIO
 BytesIO = io.BytesIO
 #@-<< imports >>
-printElements = []  # ['all','outline','head','body',]
-    # For traces.
+# For traces.
+printElements: List[str] = []  # ['all','outline','head','body',]
 #@+others
 #@+node:ekr.20060904132527.9: ** Module level
 #@+node:ekr.20060904103412.4: *3* init
@@ -252,9 +253,9 @@ class OpmlController:
         badchars.remove('\n')
         flatten = ''.join(badchars)
         pad = ' ' * len(flatten)
-        flatten = bytes(flatten, 'utf-8')
-        pad = bytes(pad, 'utf-8')
-        transtable = bytes.maketrans(flatten, pad)
+        flatten_b = bytes(flatten, 'utf-8')
+        pad_b = bytes(pad, 'utf-8')
+        transtable = bytes.maketrans(flatten_b, pad_b)
         return s.translate(transtable)
     #@+node:ekr.20141020112451.18342: *3* oc.putToOPML
     def putToOPML(self, owner):
