@@ -1,11 +1,9 @@
 #@+leo-ver=5-thin
-#@+node:danr7.20060902215215.1: * @file leo_to_html.py
-#@@language python
-#@@tabwidth -4
-
+#@+node:danr7.20060902215215.1: * @file ../plugins/leo_to_html.py
 #@+<< docstring >>
 #@+node:danr7.20060902215215.2: ** << docstring >>
-r''' Converts a leo outline to an html web page.
+r"""
+Converts a leo outline to an html web page.
 
 This plugin takes an outline stored in Leo and converts it to html which is then
 either saved in a file or shown in a browser. It is based on the original
@@ -119,73 +117,28 @@ At present, the file leo/plugins/leo_to_html.ini contains configuration
 settings. In particular, the default export path, "c:\" must be changed for \*nix
 systems.
 
-'''
+"""
 #@-<< docstring >>
-#@+<< version history >>
-#@+node:danr7.20060902215215.3: ** << version history >>
-#@@killcolor
-#@+at
-# 
-# 1.00 - Finished testing with 4 different options & outlines
-# 0.91 - Got initial headline export code working. Resolved bug in INI file checking
-# 0.90 - Created initial plug-in framework
-# 1.1 ekr: Added init method.
-# 2.0 plumloco:
-#     - made gui independent
-#     - made output xhtml compliant
-#     - added ini options
-#         - use_xhtml: 'Yes' to included xhtml headers in output.
-#         - bullet_type: 'number', 'bullet', or 'head'.
-#         - browser_command: the command needed to launch a browser.
-#     - removed bullet/headlines dialog in favour of bullet_type ini option.
-#     - added option to show output in a browser instead of saving to a file
-#     - added extra menu items to save/show current node only
-#     - added export-html-*-* commands
-#     - added show-html-*-* commands
-#     - added Leo_to_HTML object so all the plugins functionality can be scripted.
-# 2.1 plumloco:
-#     - fixed bug in export of single nodes
-#     - fixed to use tempdir to get a temp dir
-#     - improved (and spellchecked :) docstring.
-#     - added abspath module level method
-# 2.2 bobjack:
-#     - fixed tempdir bug
-#     - converted docstring to rst
-#     - removed trace
-# 2.3 bobjack:
-#     - adopt 'every method must have a docstring' ( however inane :) ) rule
-#     - added support for @string leo_to_html_no_menus setting.
-#     - changed browser_command property default to empty string
-#     - use webbrowser module if browser_command property is empty or does not work.
-# 
-# 
-# 
-# 
-#@-<< version history >>
+
+# Edited by plumloco, bobjack, and EKR.
+
 #@+<< imports >>
 #@+node:danr7.20060902215215.4: ** << imports >>
-import leo.core.leoGlobals as g
-
-if g.isPython3:
-    import configparser as ConfigParser
-else:
-    import ConfigParser
-
-import subprocess
-import webbrowser
-import tempfile
+import configparser as ConfigParser
 import os
-
+import subprocess
+import tempfile
+from typing import List
+import webbrowser
+from leo.core import leoGlobals as g
 #@-<< imports >>
 
-__version__ = '2.3'
-
 #@+others
 #@+node:bob.20080107154936: ** module level functions
 #@+node:bob.20080107154936.1: *3* init
-def init ():
-    '''Return True if the plugin has loaded successfully.'''
-    g.registerHandler("create-optional-menus",createExportMenus)
+def init():
+    """Return True if the plugin has loaded successfully."""
+    g.registerHandler("create-optional-menus", createExportMenus)
     g.registerHandler('after-create-leo-frame', onCreate)
     g.plugin_signon(__name__)
     # I think this should be ok for unit testing.
@@ -203,7 +156,7 @@ def abspath(*args):
 
     return g.os_path_finalize_join(*args)
 #@+node:bob.20080107154936.3: *3* onCreate
-def onCreate (tag, keys):
+def onCreate(tag, keys):
 
     """
     Handle 'after-create-leo-frame' hooks by creating a plugin
@@ -213,7 +166,7 @@ def onCreate (tag, keys):
     if c:
         pluginController(c)
 #@+node:bob.20080107154936.4: *3* createExportMenus
-def createExportMenus (tag,keywords):
+def createExportMenus(tag, keywords):
 
     """Create menu items in File -> Export menu.
 
@@ -237,18 +190,18 @@ def createExportMenus (tag,keywords):
         ('Save Outline as HTML', 'export-html'),
     ):
         c.frame.menu.insert('Export...', 3,
-            label = item,
-            command = lambda c = c, cmd=cmd: c.k.simulateCommand(cmd)
+            label=item,
+            command=lambda c=c, cmd=cmd: c.k.simulateCommand(cmd)
         )
 #@+node:bob.20080107154757: ** class pluginController
-class pluginController(object):
+class pluginController:
     """A per commander plugin controller to create and handle
     minibuffer commands that control the plugins functions.
     """
 
     #@+others
     #@+node:bob.20080107154757.1: *3* __init__(pluginController, leo_to_html.py)
-    def __init__ (self,c):
+    def __init__(self, c):
         """
         Initialze pluginController by registering minibuffer commands.
         """
@@ -275,7 +228,7 @@ class pluginController(object):
             'show-html-node-number',
             'show-html-node-head'
         ):
-            method = getattr(self, command.replace('-','_'))
+            method = getattr(self, command.replace('-', '_'))
             c.k.registerCommand(command, method)
     #@+node:bob.20080107154757.3: *3* export_html
     # EXPORT ALL
@@ -300,7 +253,7 @@ class pluginController(object):
     # EXPORT NODE
 
 
-    def export_html_node(self,event=None, bullet=None,):
+    def export_html_node(self, event=None, bullet=None,):
         """Command handler for leo_to_html. See modules docstring for details."""
         self.export_html(bullet=bullet, node=True)
 
@@ -356,7 +309,7 @@ class pluginController(object):
         self.show_html_node(bullet='head')
     #@-others
 #@+node:bob.20080107154746: ** class Leo_to_HTML
-class Leo_to_HTML(object):
+class Leo_to_HTML:
 
     """
     This class provides all the functionality of the leo_to_html plugin.
@@ -389,7 +342,7 @@ class Leo_to_HTML(object):
         wraper code to turn it into a file.
         """
 
-        self.xhtml = xhtml = []
+        xhtml: List[str] = []
 
         if node:
             root = self.c.p
@@ -417,8 +370,6 @@ class Leo_to_HTML(object):
             xhtml.append(self.closeLevelString)
 
         self.xhtml = '\n'.join(xhtml)
-
-
     #@+node:bob.20080107160008: *4* doItemHeadlineTags
     def doItemHeadlineTags(self, p, level=1):
         """" Recursivley proccess an outline node into an xhtml list."""
@@ -426,7 +377,7 @@ class Leo_to_HTML(object):
         self.doBodyElement(p, level)
         if p.hasChildren() and self.showSubtree(p):
             for item in p.children():
-                self.doItemHeadlineTags(item, level+1)
+                self.doItemHeadlineTags(item, level + 1)
     #@+node:bob.20080107165629: *4* doItemBulletList
     def doItemBulletList(self, p):
         """" Recursivley proccess an outline node into an xhtml list."""
@@ -457,12 +408,13 @@ class Leo_to_HTML(object):
             return
 
         h = '%s' % min(level, 6)
-        self.xhtml.append( self.openHeadlineString % h + headline + self.closeHeadlineString % h)
+        self.xhtml.append(self.openHeadlineString % h + headline + self.closeHeadlineString % h)
     #@+node:bob.20080107154746.6: *4* doBodyElement
     def doBodyElement(self, pp, level=None):
         """Append wrapped body string to output stream."""
 
-        if not self.include_body: return
+        if not self.include_body:
+            return
 
         self.xhtml.append(
             self.openBodyString +
@@ -481,8 +433,9 @@ class Leo_to_HTML(object):
         """
 
         s = p.h
-        if not self.flagIgnoreFiles or s[:len('@file')] != '@file':
+        if not self.flagIgnoreFiles or s[: len('@file')] != '@file':
             return True
+        return False
     #@+node:bob.20080107154746.9: *3* main
     def main(self, bullet=None, show=False, node=False):
         """Generate the html and write the files.
@@ -528,7 +481,7 @@ class Leo_to_HTML(object):
         self.announce(msg, prefix, color)
 
     def announce_fail(self, msg='failed', prefix=None, color=None):
-        self.announce(msg, prefix, color= color or self.errorColor, silent=False)
+        self.announce(msg, prefix, color=color or self.errorColor, silent=False)
     #@+node:bob.20080107154746.11: *3* loadConfig
     def loadConfig(self):
 
@@ -536,36 +489,39 @@ class Leo_to_HTML(object):
 
         def config(s):
 
-            ss = self.c.config.getString("leo_to_html_%s"%s)
+            ss = self.c.config.getString("leo_to_html_%s" % s)
             if ss is None:
                 s = configParser.get("Main", s)
             else:
                 s = ss
-            if not s: s = ''
+            if not s:
+                s = ''
             return s.strip()
 
         def flag(s):
             ss = config(s)
-            if ss: return ss.lower()[0] in ('y', 't', '1')
+            if ss:
+                return ss.lower()[0] in ('y', 't', '1')
+            return None
 
-        fileName = abspath(g.app.loadDir,"..","plugins","leo_to_html.ini")
+        fileName = abspath(g.app.loadDir, "..", "plugins", "leo_to_html.ini")
         configParser = ConfigParser.ConfigParser()
         configParser.read(fileName)
 
-        self.flagIgnoreFiles =  flag("flagIgnoreFiles")
+        self.flagIgnoreFiles = flag("flagIgnoreFiles")
         self.include_body = not flag("flagJustHeadlines")
 
-        self.basedir = config("exportPath") # "/"
+        self.basedir = config("exportPath")  # "/"
 
         self.browser_command = config("browser_command").strip()
 
-        self.use_xhtml =  flag("use_xhtml")
+        self.use_xhtml = flag("use_xhtml")
         if self.use_xhtml:
             self.template = self.getXHTMLTemplate()
         else:
             self.template = self.getPlainTemplate()
 
-        self.bullet_type = config( "bullet_type").lower()
+        self.bullet_type = config("bullet_type").lower()
         if self.bullet_type not in ('bullet', 'number', 'head'):
             self.bulletType = 'number'
 
@@ -609,14 +565,14 @@ class Leo_to_HTML(object):
             self.closeBlockquoteString = '</div>'
 
 
-        myFileName = self.c.frame.shortFileName()    # Get current outline filename
+        myFileName = self.c.frame.shortFileName()  # Get current outline filename
         if not myFileName:
             myFileName = 'untitiled'
 
         self.title = myFileName
 
         if myFileName[-4:].lower() == '.leo':
-            myFileName = myFileName[:-4]    # Remove .leo suffix
+            myFileName = myFileName[:-4]  # Remove .leo suffix
 
         self.myFileName = myFileName + '.html'
     #@+node:bob.20080107154746.10: *3* applyTemplate
@@ -637,7 +593,7 @@ class Leo_to_HTML(object):
         if template is None:
             template = self.template
 
-        self.xhtml = template%(
+        self.xhtml = template % (
             self.title,
             xhtml
         )
@@ -652,34 +608,24 @@ class Leo_to_HTML(object):
         Setting browser_command to a bad command will slow down browser launch.
 
         """
-
-        tempdir = g.os_path_finalize_join(tempfile.gettempdir(),'leo_show')
-
+        tempdir = g.os_path_finalize_join(tempfile.gettempdir(), 'leo_show')
         if not g.os_path_exists(tempdir):
             os.mkdir(tempdir)
-
         filename = g.sanitize_filename(self.myFileName)
         filepath = g.os_path_finalize_join(tempdir, filename + '.html')
-
         self.write(filepath, self.xhtml, basedir='', path='')
-
         url = "file://%s" % filepath
-
         msg = ''
         if self.browser_command:
-
             g.trace(self.browser_command)
-
             try:
                 subprocess.Popen([self.browser_command, url])
-                return True
+                return
             except Exception:
-                msg = 'can\'t open browser using \n    %s\n'%self.browser_command + \
+                msg = 'can\'t open browser using \n    %s\n' % self.browser_command + \
                 'Using default browser instead.'
-
         if msg:
             self.announce_fail(msg)
-
         webbrowser.open(url)
     #@+node:bob.20080107171331: *3* writeall
     def writeall(self):
@@ -702,12 +648,12 @@ class Leo_to_HTML(object):
             basedir = self.basedir
         if path is None:
             path = self.path
-        filepath = abspath(basedir,path,name)
+        filepath = abspath(basedir, path, name)
         try:
             f = open(filepath, 'wb')
         except Exception:
             g.error('can not open: %s' % (filepath))
-            g.es_exception(full=False,c=self.c)
+            g.es_exception(full=False, c=self.c)
             return False
         try:
             try:
@@ -717,7 +663,7 @@ class Leo_to_HTML(object):
                 ok = True
             except Exception:
                 g.error('write failed: %s' % (filepath))
-                g.es_exception(full=False,c=self.c)
+                g.es_exception(full=False, c=self.c)
                 ok = False
         finally:
             f.close()
@@ -767,4 +713,6 @@ class Leo_to_HTML(object):
     """
     #@-others
 #@-others
+#@@language python
+#@@tabwidth -4
 #@-leo
